@@ -227,7 +227,7 @@ public class QualityTools {
 					final int x=AminoAcid.baseToNumber[b];
 					final int x2=AminoAcid.baseToComplementNumber[b];
 					kmer=((kmer<<2)|x)&mask;
-					rkmer=(rkmer>>>2)|(x2<<shift2);
+					rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 					
 					if(x<0){len=0; rkmer=0;}else{len++;}
 					if(len>=keylen){
@@ -261,7 +261,7 @@ public class QualityTools {
 					final int x=AminoAcid.baseToNumber[b];
 					final int x2=AminoAcid.baseToComplementNumber[b];
 					kmer=((kmer<<2)|x)&mask;
-					rkmer=(rkmer>>>2)|(x2<<shift2);
+					rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 					
 					if(x<0){len=0; rkmer=0;}else{len++;}
 					if(len>=keylen){
