@@ -18,6 +18,8 @@ import fileIO.TextStreamWriter;
 import jgi.BBMerge;
 import kmer.AbstractKmerTableSet;
 import kmer.HashBuffer;
+import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -96,7 +98,7 @@ public abstract class Tadpole extends ShaveObject{
 			if(a.equals("k")){
 				k=Integer.parseInt(b);
 			}else if(a.equals("tad2") || a.equals("tadpole2")){
-				FORCE_TADPOLE2=Tools.parseBoolean(b);
+				FORCE_TADPOLE2=Parse.parseBoolean(b);
 			}
 		}
 		return Kmer.getMult(k)*Kmer.getK(k);
@@ -196,40 +198,40 @@ public abstract class Tadpole extends ShaveObject{
 			}else if(a.equals("buildthreads") || a.equals("bt")){
 				BUILD_THREADS=Integer.parseInt(b);
 			}else if(a.equals("processcontigs")){
-				processContigs=Tools.parseBoolean(b);
+				processContigs=Parse.parseBoolean(b);
 			}else if(a.equals("pop") || a.equalsIgnoreCase("popBubbles")){
-				popBubbles=Tools.parseBoolean(b);
+				popBubbles=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("bubblePasses")){
 				bubblePasses=Tools.max(1, Integer.parseInt(b));
 			}else if(a.equalsIgnoreCase("popDirect")){
-				BubblePopper.popDirect=Tools.parseBoolean(b);
+				BubblePopper.popDirect=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("popIndirect")){
-				BubblePopper.popIndirect=Tools.parseBoolean(b);
+				BubblePopper.popIndirect=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("debranch")){
-				BubblePopper.debranch=Tools.parseBoolean(b);
+				BubblePopper.debranch=Parse.parseBoolean(b);
 			}else if(a.equals("etr") || a.equalsIgnoreCase("expandTandemRepeats")){
-				expandTandemRepeats=Tools.parseBoolean(b);
+				expandTandemRepeats=Parse.parseBoolean(b);
 				assert(false) : "TODO";
 			}else if(a.equals("outkmers") || a.equals("outk") || a.equals("dump")){
 				outKmers=b;
 			}else if(a.equals("mincounttodump")){
-				minToDump=Tools.parseIntKMG(b);
+				minToDump=Parse.parseIntKMG(b);
 			}else if(a.equals("maxcounttodump")){
-				maxToDump=Tools.parseIntKMG(b);
+				maxToDump=Parse.parseIntKMG(b);
 			}else if(a.equals("hist") || a.equals("khist")){
 				outHist=b;
 			}else if(a.equals("gchist")){
-				gcHist=Tools.parseBoolean(b);
+				gcHist=Parse.parseBoolean(b);
 			}else if(a.equals("ihist") || a.equals("inserthistogram")){
 				outInsert=b;
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("mode")){
 				assert(b!=null) : "Bad parameter: "+arg;
 				if(Tools.isDigit(b.charAt(0))){
-					processingMode=Tools.parseIntKMG(b);
+					processingMode=Parse.parseIntKMG(b);
 				}else if(b.equalsIgnoreCase("contig")){
 					processingMode=contigMode;
 				}else if(b.equalsIgnoreCase("extend")){
@@ -247,29 +249,29 @@ public abstract class Tadpole extends ShaveObject{
 				if("auto".equalsIgnoreCase(b)){
 					setUseOwnership_=false;
 				}else{
-					useOwnership_=Tools.parseBoolean(b);
+					useOwnership_=Parse.parseBoolean(b);
 					setUseOwnership_=true;
 				}
 			}else if(a.equals("showstats") || a.equals("stats")){
-				showStats=Tools.parseBoolean(b);
+				showStats=Parse.parseBoolean(b);
 			}else if(a.equals("maxextension") || a.equals("maxe")){
-				extendLeft=extendRight=Tools.parseIntKMG(b);
+				extendLeft=extendRight=Parse.parseIntKMG(b);
 			}else if(a.equals("extendright") || a.equals("er")){
-				extendRight=Tools.parseIntKMG(b);
+				extendRight=Parse.parseIntKMG(b);
 			}else if(a.equals("extendleft") || a.equals("el")){
-				extendLeft=Tools.parseIntKMG(b);
+				extendLeft=Parse.parseIntKMG(b);
 			}else if(a.equals("extensionrollback") || a.equals("extendrollback")){
-				extensionRollback=Tools.parseIntKMG(b);
+				extensionRollback=Parse.parseIntKMG(b);
 			}else if(a.equals("minextension") || a.equals("mine")){
-				minExtension=Tools.parseIntKMG(b);
+				minExtension=Parse.parseIntKMG(b);
 			}else if(a.equals("maxcontiglength") || a.equals("maxcontig") || a.equals("maxlength") || a.equals("maxlen") || a.equals("maxc")){
-				maxContigLen=Tools.parseIntKMG(b);
+				maxContigLen=Parse.parseIntKMG(b);
 				if(maxContigLen<0){maxContigLen=1000000000;}
 			}else if(a.equals("mincontiglength") || a.equals("mincontiglen") || a.equals("mincontig") || a.equals("minc")){
 				if("auto".equalsIgnoreCase(b)){
 					minContigLen=-1;
 				}else{
-					minContigLen=Tools.parseIntKMG(b);
+					minContigLen=Parse.parseIntKMG(b);
 				}
 			}else if(a.equals("mincoverage") || a.equals("mincov")){
 				minCoverage=Float.parseFloat(b);
@@ -277,66 +279,66 @@ public abstract class Tadpole extends ShaveObject{
 				if(b.equalsIgnoreCase("inf")){maxCoverage=Float.MAX_VALUE;}
 				else{maxCoverage=Float.parseFloat(b);}
 			}else if(a.equals("branchlower") || a.equals("branchlowerconst") || a.equals("blc")){
-				branchLowerConst=Tools.parseIntKMG(b);
+				branchLowerConst=Parse.parseIntKMG(b);
 			}else if(a.equals("branchmult2") || a.equals("bm2")){
-				branchMult2=Tools.parseIntKMG(b);
+				branchMult2=Parse.parseIntKMG(b);
 			}else if(a.equals("branchmult") || a.equals("branchmult1") || a.equals("bm1")){
-				branchMult1=Tools.parseIntKMG(b);
+				branchMult1=Parse.parseIntKMG(b);
 			}else if(a.equals("mincount") || a.equals("mindepth") || a.equals("min")){
-				minCountSeed=minCountExtend=Tools.parseIntKMG(b);
+				minCountSeed=minCountExtend=Parse.parseIntKMG(b);
 			}else if(a.equals("mindepthseed") || a.equals("mds") || a.equals("mincountseed") || a.equals("mcs")){
-				minCountSeed=Tools.parseIntKMG(b);
+				minCountSeed=Parse.parseIntKMG(b);
 			}else if(a.equals("mindepthextend") || a.equals("mde") || a.equals("mincountextend") || a.equals("mce")){
-				minCountExtend=Tools.parseIntKMG(b);
+				minCountExtend=Parse.parseIntKMG(b);
 			}else if(a.equals("mincountretain") || a.equals("mincr") || a.equals("mindepthretain") || a.equals("mindr")){
-				kmerRangeMin=Tools.parseIntKMG(b);
+				kmerRangeMin=Parse.parseIntKMG(b);
 			}else if(a.equals("maxcountretain") || a.equals("maxcr") || a.equals("maxdepthretain") || a.equals("maxdr")){
-				kmerRangeMax=Tools.parseIntKMG(b);
+				kmerRangeMax=Parse.parseIntKMG(b);
 			}else if(a.equals("contigpasses")){
-				contigPasses=Tools.parseIntKMG(b);
+				contigPasses=Parse.parseIntKMG(b);
 			}else if(a.equals("contigpassmult")){
 				contigPassMult=Double.parseDouble(b);
 				assert(contigPassMult>=1) : "contigPassMult must be at least 1.";
 			}else if(a.equals("threads") || a.equals("t")){
 				Shared.setThreads(b);
 			}else if(a.equals("showspeed") || a.equals("ss")){
-				showSpeed=Tools.parseBoolean(b);
+				showSpeed=Parse.parseBoolean(b);
 			}else if(a.equals("verbose")){
 //				assert(false) : "Verbose flag is currently static final; must be recompiled to change.";
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("verbose2")){
 //				assert(false) : "Verbose flag is currently static final; must be recompiled to change.";
-				verbose2=Tools.parseBoolean(b);
+				verbose2=Parse.parseBoolean(b);
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("reads") || a.startsWith("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.equals("histcolumns")){
-				histColumns=Tools.parseIntKMG(b);
+				histColumns=Parse.parseIntKMG(b);
 			}else if(a.equals("histmax")){
-				histMax=Tools.parseIntKMG(b);
+				histMax=Parse.parseIntKMG(b);
 			}else if(a.equals("histheader")){
-				histHeader=Tools.parseBoolean(b);
+				histHeader=Parse.parseBoolean(b);
 			}else if(a.equals("nzo") || a.equals("nonzeroonly")){
-				histZeros=!Tools.parseBoolean(b);
+				histZeros=!Parse.parseBoolean(b);
 			}else if(a.equals("ilb") || a.equals("ignoreleftbranches") || a.equals("ignoreleftjunctions") || a.equals("ibb") || a.equals("ignorebackbranches")){
-				extendThroughLeftJunctions=Tools.parseBoolean(b);
+				extendThroughLeftJunctions=Parse.parseBoolean(b);
 			}else if(a.equals("ibo") || a.equals("ignorebadowner")){
-				IGNORE_BAD_OWNER=Tools.parseBoolean(b);
+				IGNORE_BAD_OWNER=Parse.parseBoolean(b);
 			}else if(a.equals("tad2") || a.equals("tadpole2")){
-				FORCE_TADPOLE2=Tools.parseBoolean(b);
+				FORCE_TADPOLE2=Parse.parseBoolean(b);
 			}
 
 			else if(a.equals("maskcore") || a.equals("coremask")){
-				AbstractKmerTableSet.MASK_CORE=Kmer.MASK_CORE=Tools.parseBoolean(b);
+				AbstractKmerTableSet.MASK_CORE=Kmer.MASK_CORE=Parse.parseBoolean(b);
 			}else if(a.equals("fillfast") || a.equals("fastfill")){
-				AbstractKmerTableSet.FAST_FILL=Tools.parseBoolean(b);
+				AbstractKmerTableSet.FAST_FILL=Parse.parseBoolean(b);
 			}
 			
 			//Shaver
 			else if(a.equals("shaverinse") || a.equals("shaveandrinse") || a.equals("wash") || a.equals("sr")){
 				if(b==null || Character.isLetter(b.charAt(0))){
-					removeDeadEnds=removeBubbles=Tools.parseBoolean(b);
+					removeDeadEnds=removeBubbles=Parse.parseBoolean(b);
 				}else{
 					maxShaveDepth=Integer.parseInt(b);
 					removeDeadEnds=removeBubbles=(maxShaveDepth>0);
@@ -344,14 +346,14 @@ public abstract class Tadpole extends ShaveObject{
 				setShave=setRinse=true;
 			}else if(a.equals("shave") || a.equals("removedeadends")){
 				if(b==null || Character.isLetter(b.charAt(0))){
-					removeDeadEnds=Tools.parseBoolean(b);
+					removeDeadEnds=Parse.parseBoolean(b);
 				}else{
 					maxShaveDepth=Integer.parseInt(b);
 					removeDeadEnds=(maxShaveDepth>0);
 				}
 				setShave=true;
 			}else if(a.equals("rinse") || a.equals("shampoo") || a.equals("removebubbles")){
-				removeBubbles=Tools.parseBoolean(b);
+				removeBubbles=Parse.parseBoolean(b);
 				setRinse=true;
 			}else if(a.equals("maxshavedepth") || a.equals("shavedepth") || a.equals("msd")){
 				maxShaveDepth=Integer.parseInt(b);
@@ -360,69 +362,69 @@ public abstract class Tadpole extends ShaveObject{
 			}else if(a.equals("shaveexploredistance") || a.equals("shaveexploredist") || a.equals("exploredist") || a.equals("sed")){
 				shaveExploreDist=Integer.parseInt(b);
 			}else if(a.equals("printeventcounts")){
-				Shaver.printEventCounts=Tools.parseBoolean(b);
+				Shaver.printEventCounts=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("startFromHighCounts")){
-				Shaver.startFromHighCounts=Tools.parseBoolean(b);
+				Shaver.startFromHighCounts=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("shaveFast") || a.equalsIgnoreCase("fastShave")){
-				Shaver.shaveFast=Tools.parseBoolean(b);
+				Shaver.shaveFast=Parse.parseBoolean(b);
 			}
 			
 			
 			//Junk removal
 			else if(a.equals("tossjunk")){
-				tossJunk=Tools.parseBoolean(b);
+				tossJunk=Parse.parseBoolean(b);
 			}else if(a.equals("tossdepth") || a.equals("discarddepth")){
 				discardLowDepthReads=Integer.parseInt(b);
 			}else if(a.equals("lowdepthfraction") || a.equals("ldf") || a.equals("lddf")){
 				lowDepthDiscardFraction=Float.parseFloat(b);
 			}else if(a.equals("requirebothbad") || a.equals("rbb")){
-				requireBothBad=Tools.parseBoolean(b);
+				requireBothBad=Parse.parseBoolean(b);
 			}else if(a.equals("tossuncorrectable") || a.equals("tu")){
-				discardUncorrectable=Tools.parseBoolean(b);
+				discardUncorrectable=Parse.parseBoolean(b);
 			}
 			
 			//Error Correction
 			else if(a.equals("ecctail") || a.equals("eccright") || a.equals("tail")){
-				ECC_TAIL=Tools.parseBoolean(b);
+				ECC_TAIL=Parse.parseBoolean(b);
 			}else if(a.equals("pincer") || a.equals("eccpincer")){
-				ECC_PINCER=Tools.parseBoolean(b);
+				ECC_PINCER=Parse.parseBoolean(b);
 			}else if(a.equals("reassemble") || a.equals("eccreassemble")){
-				ECC_REASSEMBLE=Tools.parseBoolean(b);
+				ECC_REASSEMBLE=Parse.parseBoolean(b);
 			}else if(a.equals("rollback") || a.equals("eccrollback")){
-				ECC_ROLLBACK=Tools.parseBoolean(b);
+				ECC_ROLLBACK=Parse.parseBoolean(b);
 			}else if(a.equals("bidirectional") || a.equals("requirebidirectional") || a.equals("eccbidirectional") || a.equals("rbi") || a.equals("rb")){
-				ECC_REQUIRE_BIDIRECTIONAL=Tools.parseBoolean(b);
+				ECC_REQUIRE_BIDIRECTIONAL=Parse.parseBoolean(b);
 			}else if(a.equals("eccall") || a.equals("eccfull")){
-				ECC_ALL=Tools.parseBoolean(b);
+				ECC_ALL=Parse.parseBoolean(b);
 			}else if(a.equals("aecc") || a.equals("aec") || a.equals("aggressive")){
-				ECC_AGGRESSIVE=Tools.parseBoolean(b);
+				ECC_AGGRESSIVE=Parse.parseBoolean(b);
 				if(ECC_AGGRESSIVE){
 					ECC_CONSERVATIVE=false;
 					ecc_=setEcc_=true;
 				}
 			}else if(a.equals("cecc") || a.equals("cec") || a.equals("conservative")){
-				ECC_CONSERVATIVE=Tools.parseBoolean(b);
+				ECC_CONSERVATIVE=Parse.parseBoolean(b);
 				if(ECC_CONSERVATIVE){
 					ECC_AGGRESSIVE=false;
 					ecc_=setEcc_=true;
 				}
 			}else if(a.equals("ecc") || a.equals("ecct")){
-				ecc_=Tools.parseBoolean(b);
+				ecc_=Parse.parseBoolean(b);
 				setEcc_=true;
 			}else if(a.equals("ecco")){
-				ecco_=Tools.parseBoolean(b);
+				ecco_=Parse.parseBoolean(b);
 			}else if(a.equals("merge")){
-				merge_=Tools.parseBoolean(b);
+				merge_=Parse.parseBoolean(b);
 			}else if(a.equals("testmerge")){
-				testMerge_=Tools.parseBoolean(b);
+				testMerge_=Parse.parseBoolean(b);
 			}else if(a.equals("testmergewidth")){
 				testMergeWidth=Integer.parseInt(b);
 			}else if(a.equals("testmergethresh")){
 				testMergeThresh=Integer.parseInt(b);
 			}else if(a.equals("testmergemult")){
-				testMergeMult=Tools.parseKMG(b);
+				testMergeMult=Parse.parseKMG(b);
 			}else if(a.equals("vstrict")){
-				vstrict_=Tools.parseBoolean(b);
+				vstrict_=Parse.parseBoolean(b);
 			}else if(a.equals("ep") || a.equals("errorpath")){
 				errorPath=Integer.parseInt(b);
 			}else if(a.equals("em1") || a.equals("errormult1")){
@@ -463,9 +465,9 @@ public abstract class Tadpole extends ShaveObject{
 				if(b==null){b="1";}
 				MARK_BAD_BASES=Integer.parseInt(b);
 			}else if(a.equals("mdo") || a.equals("markdeltaonly")){
-				MARK_DELTA_ONLY=Tools.parseBoolean(b);
+				MARK_DELTA_ONLY=Parse.parseBoolean(b);
 			}else if(a.equals("meo") || a.equals("markerrorreadsonly")){
-				MARK_ERROR_READS_ONLY=Tools.parseBoolean(b);
+				MARK_ERROR_READS_ONLY=Parse.parseBoolean(b);
 			}else if(a.equals("mq") || a.equals("markquality")){
 				MARK_QUALITY=(byte)Integer.parseInt(b);
 			}
@@ -474,16 +476,16 @@ public abstract class Tadpole extends ShaveObject{
 			else if(a.equals("trim") || a.equals("trimends")){
 				if(b==null || Character.isLetter(b.charAt(0))){
 					if("auto".equalsIgnoreCase(b)){trimEnds=-1;}
-					else{trimEnds=Tools.parseBoolean(b) ? -1 : 0;}
+					else{trimEnds=Parse.parseBoolean(b) ? -1 : 0;}
 				}else{
 					trimEnds=Integer.parseInt(b);
 				}
 			}else if(a.equals("trimcircular") || a.equals("trimloop") || a.equals("trimlooploop")){
-				trimCircular=Tools.parseBoolean(b);
+				trimCircular=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equalsIgnoreCase("sortbuffers") || a.equalsIgnoreCase("sortbuffer")){
-				HashBuffer.SORT_BUFFERS=Tools.parseBoolean(b);
+				HashBuffer.SORT_BUFFERS=Parse.parseBoolean(b);
 			}
 			
 			else if(Parser.parseCommonStatic(arg, a, b)){
@@ -502,7 +504,7 @@ public abstract class Tadpole extends ShaveObject{
 			
 			else if(a.equals("prefilter")){
 				if(b==null){prefilter=2;}
-				else if(Character.isLetter(b.charAt(0))){prefilter=Tools.parseBoolean(b) ? 2 : 0;}
+				else if(Character.isLetter(b.charAt(0))){prefilter=Parse.parseBoolean(b) ? 2 : 0;}
 				else{prefilter=Integer.parseInt(b);}
 			}else if(KmerTableSetU.isValidArgument(a)){
 				//Do nothing
@@ -1447,7 +1449,7 @@ public abstract class Tadpole extends ShaveObject{
 			crisa=crisa_;
 			rosa=rosa_;
 			rosda=rosda_;
-			leftCounts=extendThroughLeftJunctions ? null : new int[4];
+			leftCounts=extendThroughLeftJunctions ? null : KillSwitch.allocInt1D(4);
 		}
 		
 		@Override
@@ -1692,7 +1694,7 @@ public abstract class Tadpole extends ShaveObject{
 		private final ConcurrentReadOutputStream[] rosda;
 		
 		private final int[] leftCounts;
-		private final int[] rightCounts=new int[4];
+		private final int[] rightCounts=KillSwitch.allocInt1D(4);
 		private final ErrorTracker trackerT=new ErrorTracker();
 		private final ByteBuilder builderT=new ByteBuilder();
 		private final ByteBuilder builderT2=new ByteBuilder();
