@@ -287,7 +287,7 @@ public class BloomFilter implements Serializable {
 			long x=AminoAcid.baseToNumber[b];
 			long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<bitsPerBase)|x)&mask;
-			rkmer=(rkmer>>>bitsPerBase)|(x2<<shift2);
+			rkmer=((rkmer>>>bitsPerBase)|(x2<<shift2))&mask;
 			if(x<0){len=0; rkmer=0;}else{len++;}
 			if(len>=k){
 				counted++;
@@ -322,7 +322,7 @@ public class BloomFilter implements Serializable {
 			long x=AminoAcid.baseToNumber[b];
 			long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<bitsPerBase)|x)&mask;
-			rkmer=(rkmer>>>bitsPerBase)|(x2<<shift2);
+			rkmer=((rkmer>>>bitsPerBase)|(x2<<shift2))&mask;
 			if(x<0){len=0; rkmer=0;}else{len++;}
 			if(len>=k){
 				counted++;
@@ -364,7 +364,7 @@ public class BloomFilter implements Serializable {
 			long x=AminoAcid.baseToNumber[b];
 			long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<bitsPerBase)|x)&mask;
-			rkmer=(rkmer>>>bitsPerBase)|(x2<<shift2);
+			rkmer=((rkmer>>>bitsPerBase)|(x2<<shift2))&mask;
 			if(x<0){len=0; rkmer=0;}
 			else{
 				len++;
@@ -391,7 +391,7 @@ public class BloomFilter implements Serializable {
 			long x=AminoAcid.baseToNumber[b];
 			long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<bitsPerBase)|x)&mask;
-			rkmer=(rkmer>>>bitsPerBase)|(x2<<shift2);
+			rkmer=((rkmer>>>bitsPerBase)|(x2<<shift2))&mask;
 			if(x<0){len=0; rkmer=0;}
 			else{
 				len++;
@@ -419,7 +419,7 @@ public class BloomFilter implements Serializable {
 			long x=AminoAcid.baseToNumber[b];
 			long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<bitsPerBase)|x)&mask;
-			rkmer=(rkmer>>>bitsPerBase)|(x2<<shift2);
+			rkmer=((rkmer>>>bitsPerBase)|(x2<<shift2))&mask;
 			if(x<0){len=0; rkmer=0;}else{len++;}
 			if(len>=k){
 				boolean found=contains(kmer, rkmer, thresh);
@@ -461,7 +461,7 @@ public class BloomFilter implements Serializable {
 			long x=AminoAcid.baseToNumber[b];
 			long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<bitsPerBase)|x)&mask;
-			rkmer=(rkmer>>>bitsPerBase)|(x2<<shift2);
+			rkmer=((rkmer>>>bitsPerBase)|(x2<<shift2))&mask;
 			if(x<0){
 				if(len>=k){keys.add(-1);}
 				len=0;
@@ -523,7 +523,7 @@ public class BloomFilter implements Serializable {
 			final long x=AminoAcid.baseToNumber[base];
 			final long x2=AminoAcid.baseToComplementNumber[base];
 			kmer=((kmer<<bitsPerBase)|x)&mask;
-			rkmer=(rkmer>>>bitsPerBase)|(x2<<shift2);
+			rkmer=((rkmer>>>bitsPerBase)|(x2<<shift2))&mask;
 			
 			if(x<0){
 				len=0;
