@@ -12,6 +12,7 @@ import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import jgi.BBMerge;
+import shared.KillSwitch;
 import shared.MetadataWriter;
 import shared.Parse;
 import shared.Parser;
@@ -134,6 +135,8 @@ public class BloomFilterCorrectorWrapper {
 				minCount_=Integer.parseInt(b);
 			}else if(a.equals("minprob")){
 				KmerCount7MTA.minProb=Float.parseFloat(b);
+			}else if(a.equals("maxload")){
+				maxLoad=Float.parseFloat(b);
 			}else if(a.equals("requireboth")){
 				requireBothToPass_=Parse.parseBoolean(b);
 			}else if(a.equals("ecc")){
@@ -374,6 +377,14 @@ public class BloomFilterCorrectorWrapper {
 				double b=filter.filter.estimateUniqueKmersFromUsedFraction(hashes, usedFraction2);
 				outstream.println("Estimated kmers of depth 2+: \t"+(long)b);
 				outstream.println("Used fraction for depth 2+:  \t"+String.format(Locale.ROOT, "%.3f%%", usedFraction2*100));
+				if(usedFraction2>maxLoad){
+					KillSwitch.kill("Max load exceeded, quitting: "+usedFraction2+" > "+maxLoad);
+				}
+			}else if(maxLoad<1.0f){
+				double usedFraction=filter.filter.usedFraction(2);
+				if(usedFraction>maxLoad){
+					KillSwitch.kill("Max load exceeded, quitting: "+usedFraction+" > "+maxLoad);
+				}
 			}
 		}
 	}
@@ -968,6 +979,7 @@ public class BloomFilterCorrectorWrapper {
 	final boolean ustrict;
 	final int junkWidth;
 	float memFraction=1.0f;
+	float maxLoad=1.0f; //Crash if this is exceeded
 	
 	int testMergeWidth=4;
 	long testMergeMult=80L;
