@@ -167,7 +167,7 @@ public class KmerComparator implements Comparator<Read> {
 			long x=AminoAcid.baseToNumber[b];
 			long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			
 			if(minProb>0 && quals!=null){//Update probability
 				prob=prob*PROB_CORRECT[quals[i]];
@@ -243,6 +243,156 @@ public class KmerComparator implements Comparator<Read> {
 		return key.kmer;
 	}
 	
+
+	
+	/* For teaching */
+	/** Finds the global maximum, forward only */
+	public long example1(Read r){
+		//Handle degenerate reads shorter than kmer length
+		if(r.length()<k){return fillShort(r, null);}
+		
+		final byte[] bases=r.bases;
+		long kmer=0;//Stores the current kmer being built and analyzed
+		int len=0;//Length bases since last N encountered
+		
+		long topCode=Long.MIN_VALUE;//Maximal hash code encountered
+		long topKmer=Long.MIN_VALUE;//Kmer for maximal hash code
+		
+		for(int i=0; i<bases.length; i++){
+			byte b=bases[i];//The base, A, C, G, T, or N
+			long x=AminoAcid.baseToNumber[b];//2-bit value, 0, 1, 2, 3, or -1
+			kmer=((kmer<<2)|x)&mask;//Shift the new 2 bits into the kmer
+			
+			if(x<0){//If an N is encountered, reset the length
+				len=0;
+			}else{len++;}
+			
+			if(len>=k){//If the kmer is valid and full length, hash it
+				final long code=hash(kmer);//Some arbitrary hash function
+				
+				if(code>topCode){//If this is a new maximum, retain it
+					topKmer=kmer;
+					topCode=code;
+				}
+			}
+		}
+		
+		//If for whatever reason it failed (e.g., Ns), use the short method
+		if(topCode==Long.MIN_VALUE){return fillShort(r, null);}
+		
+		//Return the pivot kmer.
+		//It's also useful to store (and return) the position and orientation.
+		return topKmer;
+	}
+	
+	/* For teaching */
+	/** Finds the global maximum, forward and reverse */
+	public long example2(Read r){
+		if(r.length()<k){return fillShort(r, null);}
+		
+		final byte[] bases=r.bases;
+		long kmer=0;
+		long rkmer=0;
+		int len=0;
+		
+		if(bases==null || bases.length<k){return -1;}
+		
+		long topCode=Long.MIN_VALUE;
+		long topKmer=Long.MIN_VALUE;
+		
+		for(int i=0; i<bases.length; i++){
+			byte b=bases[i];
+			long x=AminoAcid.baseToNumber[b];
+			long x2=AminoAcid.baseToComplementNumber[b];
+			kmer=((kmer<<2)|x)&mask;
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
+			
+			if(x<0){
+				len=0;
+			}else{len++;}
+			
+			if(len>=k){
+				final long kmax=Tools.max(kmer, rkmer);
+				final long code=hash(kmax);
+				
+				if(code>topCode){
+					topKmer=kmax;
+					topCode=code;
+				}
+			}
+		}
+		if(topCode==Long.MIN_VALUE){
+			return fillShort(r, null);
+		}
+		
+		return topKmer;
+	}
+
+	/* For teaching */
+	/** Finds the global maximum, forward and reverse, with qualities and border */
+	public long example3(Read r){
+		if(r.length()<k){return fillShort(r, null);}
+		
+		final byte[] bases=r.bases, quals=r.quality;
+		long kmer=0;
+		long rkmer=0;
+		int len=0;
+		float prob=1;
+		
+		if(bases==null || bases.length<k){return -1;}
+		
+		long topCode=Long.MIN_VALUE;
+		long topKmer=Long.MIN_VALUE;
+		float topProb=0;
+		final int localBorder=(bases.length>k+4*border ? border : 0);
+		
+		final int max=bases.length-localBorder;
+		for(int i=localBorder; i<max; i++){
+			byte b=bases[i];
+			long x=AminoAcid.baseToNumber[b];
+			long x2=AminoAcid.baseToComplementNumber[b];
+			kmer=((kmer<<2)|x)&mask;
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
+			
+			if(minProb>0 && quals!=null){//Update probability
+				prob=prob*PROB_CORRECT[quals[i]];
+				if(len>k){
+					byte oldq=quals[i-k];
+					prob=prob*PROB_CORRECT_INVERSE[oldq];
+				}
+			}
+			
+			if(x<0){
+				len=0;
+				prob=1;
+			}else{len++;}
+			
+			if(len>=k){
+				final long kmax=Tools.max(kmer, rkmer);
+				final long code=hash(kmax);
+				boolean accept=false;
+				
+				if(code>topCode){
+					accept=(prob>=minProb || topProb<minProb);
+				}else{
+					accept=(prob>=minProb && topProb<minProb);
+				}
+				
+				if(accept){
+					topKmer=kmax;
+					topCode=code;
+					topProb=minProb;
+				}
+			}
+		}
+		if(topCode==Long.MIN_VALUE){
+			return fillShort(r, null);
+		}
+		
+		return topKmer;
+	}
+	
+	/** Generates a key when the read is shorter than k */
 	public long fillShort(Read r, ReadKey key){
 		final byte[] bases=r.bases;
 		final int max=Tools.min(bases.length, k);
@@ -255,7 +405,7 @@ public class KmerComparator implements Comparator<Read> {
 			long x=AminoAcid.baseToNumber0[b];
 			long x2=AminoAcid.baseToComplementNumber0[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 		}
 
 		final long kmax=Tools.max(kmer, rkmer);
@@ -273,6 +423,7 @@ public class KmerComparator implements Comparator<Read> {
 		defaultHashes=Tools.mid(0, x, 8);
 	}
 	
+	//TODO:  This can be swapped with BBSketch hashing code.  Check speed.
 	public final long hash(long kmer){
 		long code=kmer;
 		for(int i=0; i<hashes; i++){//4 only half-hashes; 8 does full hashing
