@@ -10,6 +10,7 @@ import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import jgi.BBMerge;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -90,7 +91,7 @@ public class KmerSort3 extends KmerSort {
 			String b=split.length>1 ? split[1] : null;
 
 			if(a.equals("verbose")){
-				verbose=KmerComparator.verbose=Tools.parseBoolean(b);
+				verbose=KmerComparator.verbose=Parse.parseBoolean(b);
 			}else if(a.equals("parse_flag_goes_here")){
 				//Set a variable here
 			}else if(a.equals("k")){
@@ -99,32 +100,32 @@ public class KmerSort3 extends KmerSort {
 			}else if(a.equals("mincount") || a.equals("mincr")){
 				minCount=Integer.parseInt(b);
 			}else if(a.equals("rename") || a.equals("addname")){
-				addName=Tools.parseBoolean(b);
+				addName=Parse.parseBoolean(b);
 			}else if(a.equals("shortname") || a.equals("shortnames")){
 				if(b!=null && b.equals("shrink")){
 					shrinkName=true;
 				}else{
 					shrinkName=false;
-					shortName=Tools.parseBoolean(b);
+					shortName=Parse.parseBoolean(b);
 				}
 			}else if(a.equals("rcomp") || a.equals("reversecomplement")){
-				rcomp=Tools.parseBoolean(b);
+				rcomp=Parse.parseBoolean(b);
 			}else if(a.equals("ecco")){
-				ecco=Tools.parseBoolean(b);
+				ecco=Parse.parseBoolean(b);
 			}else if(a.equals("condense") || a.equals("consensus") || a.equals("concensus")){//Note the last one is intentionally misspelled
-				condense=Tools.parseBoolean(b);
+				condense=Parse.parseBoolean(b);
 			}else if(a.equals("correct") || a.equals("ecc")){
-				correct=Tools.parseBoolean(b);
+				correct=Parse.parseBoolean(b);
 			}else if(a.equals("passes")){
 				passes=Integer.parseInt(b);
 			}
 			
 			else if(a.equals("dedupe")){
-				dedupe=Tools.parseBoolean(b);
+				dedupe=Parse.parseBoolean(b);
 			}else if(a.equals("markduplicates")){
-				dedupe=Clump.markOnly=Tools.parseBoolean(b);
+				dedupe=Clump.markOnly=Parse.parseBoolean(b);
 			}else if(a.equals("markall")){
-				boolean x=Tools.parseBoolean(b);
+				boolean x=Parse.parseBoolean(b);
 				if(x){
 					dedupe=Clump.markOnly=Clump.markAll=true;
 				}else{
@@ -133,7 +134,7 @@ public class KmerSort3 extends KmerSort {
 			}
 			
 			else if(a.equals("prefilter")){
-				KmerReduce.prefilter=Tools.parseBoolean(b);
+				KmerReduce.prefilter=Parse.parseBoolean(b);
 			}else if(a.equals("groups") || a.equals("g") || a.equals("sets") || a.equals("ways")){
 				groups=Integer.parseInt(b);
 				splitInput=(groups>1);
@@ -147,18 +148,18 @@ public class KmerSort3 extends KmerSort {
 				KmerComparator.minProb=Float.parseFloat(b);
 				
 			}else if(a.equals("unpair")){
-				unpair=Tools.parseBoolean(b);
+				unpair=Parse.parseBoolean(b);
 			}else if(a.equals("repair")){
-				repair=Tools.parseBoolean(b);
+				repair=Parse.parseBoolean(b);
 			}else if(a.equals("namesort") || a.equals("sort")){
-				namesort=Tools.parseBoolean(b);
+				namesort=Parse.parseBoolean(b);
 			}else if(a.equals("fetchthreads")){
 				fetchThreads=Integer.parseInt(b);
 				assert(fetchThreads>0) : fetchThreads+"\nFetch threads must be at least 1.";
 			}else if(a.equals("reorder") || a.equals("reorderclumps")){
-				//reorder=Tools.parseBoolean(b);
+				//reorder=Parse.parseBoolean(b);
 			}else if(a.equals("reorderpaired") || a.equals("reorderclumpspaired")){
-//				reorderpaired=Tools.parseBoolean(b);
+//				reorderpaired=Parse.parseBoolean(b);
 			}
 			
 			else if(Clump.parseStatic(arg, a, b)){
