@@ -10,6 +10,7 @@ import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import jgi.BBMerge;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -89,7 +90,7 @@ public class KmerSplit {
 			if(parser.parse(arg, a, b)){
 				//do nothing
 			}else if(a.equals("verbose")){
-				verbose=KmerComparator.verbose=Tools.parseBoolean(b);
+				verbose=KmerComparator.verbose=Parse.parseBoolean(b);
 			}else if(a.equals("parse_flag_goes_here")){
 				//Set a variable here
 			}else if(a.equals("k")){
@@ -101,16 +102,16 @@ public class KmerSplit {
 				groups=Integer.parseInt(b);
 			}else if(a.equals("rename") || a.equals("addname")){
 				//Do nothing
-//				addName=Tools.parseBoolean(b);
+//				addName=Parse.parseBoolean(b);
 			}else if(a.equals("shortname") || a.equals("shortnames")){
 				if(b!=null && b.equals("shrink")){
 					shrinkName=true;
 				}else{
 					shrinkName=false;
-					shortName=Tools.parseBoolean(b);
+					shortName=Parse.parseBoolean(b);
 				}
 			}else if(a.equals("rcomp") || a.equals("reversecomplement")){
-				//ignore rcomp=Tools.parseBoolean(b);
+				//ignore rcomp=Parse.parseBoolean(b);
 			}else if(a.equals("condense") || a.equals("consensus") || a.equals("concensus")){//Note the last one is intentionally misspelled
 				//ignore
 			}else if(a.equals("correct") || a.equals("ecc")){
@@ -153,9 +154,9 @@ public class KmerSplit {
 			}
 			
 			else if(a.equals("prefilter")){
-				KmerReduce.prefilter=Tools.parseBoolean(b);
+				KmerReduce.prefilter=Parse.parseBoolean(b);
 			}else if(a.equals("ecco")){
-				ecco=Tools.parseBoolean(b);
+				ecco=Parse.parseBoolean(b);
 			}else if(a.equals("seed")){
 				KmerComparator.defaultSeed=Long.parseLong(b);
 			}else if(a.equals("hashes")){
@@ -165,7 +166,7 @@ public class KmerSplit {
 			}else if(a.equals("minprob")){
 				KmerComparator.minProb=Float.parseFloat(b);
 			}else if(a.equals("unpair")){
-				unpair=Tools.parseBoolean(b);
+				unpair=Parse.parseBoolean(b);
 			}else if(a.equals("repair")){
 				//Do nothing
 			}else if(a.equals("namesort") || a.equals("sort")){
@@ -173,9 +174,9 @@ public class KmerSplit {
 			}else if(a.equals("fetchthreads")){
 				//Do nothing
 			}else if(a.equals("reorder") || a.equals("reorderclumps")){
-				//reorder=Tools.parseBoolean(b);
+				//reorder=Parse.parseBoolean(b);
 			}else if(a.equals("reorderpaired") || a.equals("reorderclumpspaired")){
-//				reorderpaired=Tools.parseBoolean(b);
+//				reorderpaired=Parse.parseBoolean(b);
 			}
 			
 			
