@@ -10,6 +10,7 @@ import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import prok.ProkObject;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -106,7 +107,7 @@ public class ConsensusMaker extends ConsensusObject implements Accumulator<Conse
 		
 		{
 //			if("auto".equalsIgnoreCase(atomic)){Scaffold.setCA3A(Shared.threads()>8);}
-//			else{Scaffold.setCA3A(Tools.parseBoolean(atomic));}
+//			else{Scaffold.setCA3A(Parse.parseBoolean(atomic));}
 
 			if(ploidy<1){System.err.println("WARNING: ploidy not set; assuming ploidy=1."); ploidy=1;}
 			samFilter.setSamtoolsFilter();
@@ -160,7 +161,7 @@ public class ConsensusMaker extends ConsensusObject implements Accumulator<Conse
 			if(b!=null && b.equalsIgnoreCase("null")){b=null;}
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				BaseGraph.verbose=verbose;
 			}else if(a.equals("ref")){
 				ref=b;
@@ -171,24 +172,24 @@ public class ConsensusMaker extends ConsensusObject implements Accumulator<Conse
 			}else if(a.equals("hist") || a.equals("histogram")){
 				outHistFile=b;
 			}else if(a.equals("realign")){
-				realign=Tools.parseBoolean(b);
+				realign=Parse.parseBoolean(b);
 			}else if(a.equals("printscores")){
-				printScores=Tools.parseBoolean(b);
+				printScores=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("useMapq")){
-				useMapq=Tools.parseBoolean(b);
+				useMapq=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("identityCeiling") || a.equalsIgnoreCase("idceiling") || a.equalsIgnoreCase("ceiling")){
 				double d=Double.parseDouble(b);
 				if(d<=2){d=d*100;}
 				identityCeiling=(int)d;
 				invertIdentity=true;
 			}else if(a.equalsIgnoreCase("invertIdentity")){
-				invertIdentity=Tools.parseBoolean(b);
+				invertIdentity=Parse.parseBoolean(b);
 			}else if(a.equals("name") || a.equals("rename") || a.equals("header")){
 				name=b;
 			}else if(a.equals("noindels")){
-				noIndels=Tools.parseBoolean(b);
+				noIndels=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("onlyConvertNs") || a.equalsIgnoreCase("nOnly") || a.equalsIgnoreCase("onlyN")){
-				onlyConvertNs=Tools.parseBoolean(b);
+				onlyConvertNs=Parse.parseBoolean(b);
 			}else if(a.equals("ploidy")){
 				ploidy=Integer.parseInt(b);
 			}else if(a.equals("mindepth")){
@@ -196,7 +197,7 @@ public class ConsensusMaker extends ConsensusObject implements Accumulator<Conse
 			}else if(a.equals("trimdepth") || a.equals("trimdepthfraction")){
 				trimDepthFraction=Float.parseFloat(b);
 			}else if(a.equalsIgnoreCase("trimNs")){
-				trimNs=Tools.parseBoolean(b);
+				trimNs=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("mafn") || a.equals("mafnoref")){
 				MAF_noref=Float.parseFloat(b);
 			}else if(a.equalsIgnoreCase("mafsub")){
@@ -210,11 +211,11 @@ public class ConsensusMaker extends ConsensusObject implements Accumulator<Conse
 			}else if(a.equalsIgnoreCase("mafindel")){
 				MAF_ins=MAF_del=Float.parseFloat(b);
 			}else if(a.equals("clearfilters")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					samFilter.clear();
 				}
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(samFilter.parse(arg, a, b)){
 				//do nothing
