@@ -11,6 +11,7 @@ import dna.AminoAcid;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -103,7 +104,7 @@ public class Lilypad implements Accumulator<Lilypad.ProcessThread> {
 		
 		{
 //			if("auto".equalsIgnoreCase(atomic)){Scaffold.setCA3A(Shared.threads()>8);}
-//			else{Scaffold.setCA3A(Tools.parseBoolean(atomic));}
+//			else{Scaffold.setCA3A(Parse.parseBoolean(atomic));}
 			samFilter.setSamtoolsFilter();
 			
 			streamerThreads=Tools.max(1, Tools.min(streamerThreads, Shared.threads()));
@@ -147,15 +148,15 @@ public class Lilypad implements Accumulator<Lilypad.ProcessThread> {
 			if(b!=null && b.equalsIgnoreCase("null")){b=null;}
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ref") || a.equals("scaffolds")){
 				ref=b;
 			}else if(a.equals("insertlist")){
 				insertList=b;
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("sameStrandPairs")){
-				sameStrandPairs=Tools.parseBoolean(b);
+				sameStrandPairs=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("ns") || a.equalsIgnoreCase("n") || a.equalsIgnoreCase("scaffoldbreak") || a.equalsIgnoreCase("gap") || a.equalsIgnoreCase("mingap")){
 				scaffoldBreakNs=Integer.parseInt(b);
 				assert(scaffoldBreakNs>0);
@@ -163,17 +164,17 @@ public class Lilypad implements Accumulator<Lilypad.ProcessThread> {
 				minDepth=Integer.parseInt(b);
 				assert(minDepth>0);
 			}else if(a.equalsIgnoreCase("maxinsert")){
-				maxPairDist=Tools.parseIntKMG(b);
+				maxPairDist=Parse.parseIntKMG(b);
 			}else if(a.equalsIgnoreCase("minWeightRatio") || a.equalsIgnoreCase("minwr")){
 				minWeightRatio=Float.parseFloat(b);
 			}else if(a.equalsIgnoreCase("minStrandRatio") || a.equalsIgnoreCase("minsr")){
 				minStrandRatio=Float.parseFloat(b);
 			}else if(a.equals("clearfilters") || a.equals("clearfilter")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					samFilter.clear();
 				}
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(samFilter.parse(arg, a, b)){
 				//do nothing
