@@ -94,7 +94,7 @@ public final class AminoAcid {
 	}
 	
 	public String canonicalCodon(){
-		return codeStrings[0];
+		return codeStrings==null || codeStrings.length<1 ? null : codeStrings[0];
 	}
 	
 	
@@ -275,6 +275,10 @@ public final class AminoAcid {
 	public static final AminoAcid Tryptophan=new AminoAcid("Tryptophan, Trp, W, UGG");
 	public static final AminoAcid Tyrosine=new AminoAcid("Tyrosine, Tyr, Y, UAU, UAC");
 	public static final AminoAcid Valine=new AminoAcid("Valine, Val, V, GUU, GUC, GUA, GUG");
+	
+	public static final AminoAcid Selenocysteine=new AminoAcid("Selenocysteine, Sec, U"); //UGA sometimes
+	public static final AminoAcid Pyrrolysine=new AminoAcid("Pyrrolysine, Pyl, O");
+	
 	public static final AminoAcid END=new AminoAcid("End, End, *, UAA, UGA, UAG");
 	public static final AminoAcid ANY=new AminoAcid("Any, Any, X, XXX");
 	
@@ -849,7 +853,9 @@ public final class AminoAcid {
 		AlphabeticalAAs[18]=Tyrosine;
 		AlphabeticalAAs[19]=Valine;
 		AlphabeticalAAs[20]=END;
-//		AlphabeticalAAs[21]=ANY;
+//		AlphabeticalAAs[21]=Selenocysteine;
+//		AlphabeticalAAs[22]=Pyrrolysine;
+//		AlphabeticalAAs[23]=ANY;
 
 		Arrays.fill(aminoToCode, (byte)-1);
 		Arrays.fill(acidToNumber, (byte)-1);
@@ -896,11 +902,13 @@ public final class AminoAcid {
 		{
 			byte anySym=(byte)(Tools.max(acidToNumberExtended)+1);
 			byte dash=(byte)(anySym+1);
-			acidToNumberExtended['x']=acidToNumberExtended['X']=acidToNumberExtended['.']=anySym;
+			acidToNumberExtended['x']=acidToNumberExtended['X']=acidToNumberExtended['.']=anySym; //Unknown
 			acidToNumberExtended['b']=acidToNumberExtended['B']=anySym;
 			acidToNumberExtended['z']=acidToNumberExtended['Z']=anySym;
 			acidToNumberExtended['j']=acidToNumberExtended['J']=anySym;
-			acidToNumberExtended['-']=dash;
+			acidToNumberExtended['u']=acidToNumberExtended['U']=anySym; //Selenocysteine
+			acidToNumberExtended['o']=acidToNumberExtended['O']=anySym; //Pyrrolysine
+			acidToNumberExtended['-']=dash; //Deletion
 		}
 		
 		acidToNumber8['H']=acidToNumber8['K']=acidToNumber8['R']=0;
@@ -913,7 +921,8 @@ public final class AminoAcid {
 		acidToNumber8['B']=acidToNumber8['Z']=7;
 
 		aminoToCode['X']=aminoToCode['x']=aminoToCode['B']=aminoToCode['b']=
-				aminoToCode['Z']=aminoToCode['z']=aminoToCode['J']=aminoToCode['j']=65;
+				aminoToCode['Z']=aminoToCode['z']=aminoToCode['J']=aminoToCode['j']=
+				aminoToCode['O']=aminoToCode['o']=aminoToCode['U']=aminoToCode['u']=65;
 		codeToAA[65]=ANY;
 		codeToChar[65]='X';
 		codeToByte[65]='X';
