@@ -8,6 +8,7 @@ import java.util.Date;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextStreamWriter;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -74,11 +75,11 @@ public class ChromArrayMaker {
 			}else if(a.equals("chroms")){
 				chroms=Integer.parseInt(b);
 			}else if(a.equals("writeinthread")){
-				WRITE_IN_THREAD=Tools.parseBoolean(b);
+				WRITE_IN_THREAD=Parse.parseBoolean(b);
 			}else if(a.equals("nodisk")){
-				NODISK=Tools.parseBoolean(b);
+				NODISK=Parse.parseBoolean(b);
 			}else if(a.equals("writeinfo")){
-				writeinfo=Tools.parseBoolean(b);
+				writeinfo=Parse.parseBoolean(b);
 			}else if(a.equals("padstart") || a.startsWith("startpad") || a.equals("padfront") || a.startsWith("frontpad")){
 				START_PADDING=Integer.parseInt(b);
 			}else if(a.equals("padstop") || a.startsWith("stoppad") || a.equals("padend") || a.startsWith("endpad")){
@@ -90,29 +91,29 @@ public class ChromArrayMaker {
 			}else if(a.startsWith("minscaf") || a.startsWith("mincontig")){
 				MIN_SCAFFOLD=Integer.parseInt(b);
 			}else if(a.equals("genscaffoldinfo")){
-				genScaffoldInfo=Tools.parseBoolean(b);
+				genScaffoldInfo=Parse.parseBoolean(b);
 				System.err.println("Set genScaffoldInfo="+genScaffoldInfo);
 			}else if(a.equals("append") || a.equals("app")){
-				append=Tools.parseBoolean(b);
+				append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("mergescaffolds") || a.equals("mergecontigs") || (a.equals("merge"))){
-				MERGE_SCAFFOLDS=Tools.parseBoolean(b);
+				MERGE_SCAFFOLDS=Parse.parseBoolean(b);
 				System.err.println("Set MERGE_SCAFFOLDS="+MERGE_SCAFFOLDS);
 			}else if(a.startsWith("maxlen") || a.startsWith("chromlen")){
-				long len=Tools.parseKMG(b);
+				long len=Parse.parseKMG(b);
 				assert(len>0 && len<=Integer.MAX_VALUE);
 				MAX_LENGTH=(int)len;
 			}else if(a.equals("writechroms")){
-				writeChroms=Tools.parseBoolean(b);
+				writeChroms=Parse.parseBoolean(b);
 			}else if(a.equals("chromgz") || a.equals("gz")){
-				Data.CHROMGZ=Tools.parseBoolean(b);
+				Data.CHROMGZ=Parse.parseBoolean(b);
 			}else if(a.equals("retain")){
-				RETAIN=Tools.parseBoolean(b);
+				RETAIN=Parse.parseBoolean(b);
 			}else if(a.equals("scafprefixes")){
-				scafprefixes=Tools.parseBoolean(b);
+				scafprefixes=Parse.parseBoolean(b);
 			}else if(a.equals("waitforwriting")){
-				WAIT_FOR_WRITING=Tools.parseBoolean(b);
+				WAIT_FOR_WRITING=Parse.parseBoolean(b);
 			}else{
 				if(i>2){
 					System.err.println("WARNING: Unknown parameter "+args[i]);
