@@ -1236,7 +1236,7 @@ public class Data {
 				}
 			}
 			if(!f.exists() && !path.startsWith("jar:")){
-				String hardlink="/global/projectb/sandbox/gaag/bbtools/resources/"+fname;
+				String hardlink="/global/cfs/cdirs/bbtools/resources/"+fname;
 				f=new File(hardlink);
 				if(f.exists()){path=hardlink;}
 				else{if(vb){System.err.println("Did not find "+fname+" at "+hardlink);}}
