@@ -10,6 +10,7 @@ import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import prok.ProkObject;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -100,7 +101,7 @@ public class CompareGff {
 				maxLines=Long.parseLong(b);
 				if(maxLines<0){maxLines=Long.MAX_VALUE;}
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 //				ByteFile1.verbose=verbose;
 //				ByteFile2.verbose=verbose;
 //				ReadWrite.verbose=verbose;
