@@ -18,6 +18,7 @@ import fileIO.ByteFile2;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -86,7 +87,7 @@ public class BBMask{
 			}else if(Parser.parseFasta(arg, a, b)){
 				//do nothing
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
@@ -94,18 +95,18 @@ public class BBMask{
 				stream.FastqReadInputStream.verbose=verbose;
 				ReadWrite.verbose=verbose;
 			}else if(a.equals("reads") || a.equals("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.equals("t") || a.equals("threads")){
 				Shared.setThreads(b);
 			}else if(a.equals("sampad") || a.equals("sampadding") || a.equals("sp")){
 				samPad=Integer.parseInt(b);
 			}else if(a.equals("entropymode")){
-				entropyMode=Tools.parseBoolean(b);
+				entropyMode=Parse.parseBoolean(b);
 				setEntropyMode=true;
 			}else if(a.equals("maskrepeats") || a.equals("mr")){
-				processRepeats=Tools.parseBoolean(b);
+				processRepeats=Parse.parseBoolean(b);
 			}else if(a.equals("masklowentropy") || a.equals("masklowcomplexity") || a.equals("mlc") || a.equals("mle") || a.equals("me")){
-				processEntropy=Tools.parseBoolean(b);
+				processEntropy=Parse.parseBoolean(b);
 			}else if(a.equals("in") || a.equals("input") || a.equals("in1") || a.equals("input1") || a.equals("ref")){
 				inRef=b;
 			}else if(a.equals("insam") || a.equals("samin") || a.equals("sam")){
@@ -125,7 +126,7 @@ public class BBMask{
 			}else if(a.equals("extout")){
 				extoutRef=b;
 			}else if(a.equals("split")){
-				splitMode=Tools.parseBoolean(b);
+				splitMode=Parse.parseBoolean(b);
 			}else if(a.equals("mink") || a.equals("kmin")){
 				mink=mink2=Integer.parseInt(b);
 			}else if(a.equals("maxk") || a.equals("kmax")){
@@ -149,7 +150,7 @@ public class BBMask{
 			}else if(a.equals("maxcov")){
 				maxcov=Integer.parseInt(b);
 			}else if(a.equals("delcov") || a.equals("delcoverage")){
-				includeDeletionCoverage=Tools.parseBoolean(b);
+				includeDeletionCoverage=Parse.parseBoolean(b);
 			}else if(a.equals("window") || a.equals("w")){
 				window=Integer.parseInt(b);
 			}else if(a.equals("ratio")){
@@ -159,15 +160,15 @@ public class BBMask{
 				entropyCutoff=Float.parseFloat(b);
 				if(!setEntropyMode){entropyMode=true;}
 			}else if(a.equals("lowercase") || a.equals("lc")){
-				MaskByLowercase=Tools.parseBoolean(b);
+				MaskByLowercase=Parse.parseBoolean(b);
 			}else if(a.equals("minlen")){
 				minlen=Integer.parseInt(b);
 			}else if(a.equals("mincount")){
 				mincount=Integer.parseInt(b);
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.startsWith("minscaf") || a.startsWith("mincontig")){
 				stream.FastaReadInputStream.MIN_READ_LEN=Integer.parseInt(b);
 			}else if(!arg.contains("=") && FileFormat.hasSamOrBamExtension(arg)){
