@@ -1080,9 +1080,9 @@ public class BBQC {
 	private String pjetRef = "/global/dna/shared/rqc/ref_databases/qaqc/databases/pJET1.2.fasta";
 
 	private String allArtifactsLatest = "/global/projectb/sandbox/rqc/qcdb/illumina.artifacts/Illumina.artifacts.fa";
-	private String fragAdapters = "/global/projectb/sandbox/gaag/bbtools/data/adapters.fa";
-	private String rnaAdapter = "/global/projectb/sandbox/gaag/bbtools/data/truseq_rna.fa.gz";
-	private String indexPath = "/global/projectb/sandbox/gaag/bbtools/hg19/";
+	private String fragAdapters = "/global/cfs/cdirs/bbtools/data/adapters.fa";
+	private String rnaAdapter = "/global/cfs/cdirs/bbtools/data/truseq_rna.fa.gz";
+	private String indexPath = "/global/cfs/cdirs/bbtools/hg19/";
 	private String mapRef = null;
 	
 	/*--------------------------------------------------------------*/
