@@ -16,6 +16,7 @@ import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextFile;
 import fileIO.TextStreamWriter;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -113,9 +114,9 @@ public class CalcTrueQuality {
 			String b=split.length>1 ? split[1] : null;
 
 			if(a.equals("showstats")){
-				showStats=Tools.parseBoolean(b);
+				showStats=Parse.parseBoolean(b);
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
@@ -123,7 +124,7 @@ public class CalcTrueQuality {
 				stream.FastqReadInputStream.verbose=verbose;
 				ReadWrite.verbose=verbose;
 			}else if(a.equals("reads") || a.equals("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.equals("t") || a.equals("threads")){
 				Shared.setThreads(b);
 			}else if(a.equals("build") || a.equals("genome")){
@@ -136,22 +137,22 @@ public class CalcTrueQuality {
 			}else if(a.equals("path")){
 				Data.setPath(b);
 			}else if(a.equals("append") || a.equals("app")){
-//				append=ReadStats.append=Tools.parseBoolean(b);
+//				append=ReadStats.append=Parse.parseBoolean(b);
 				assert(false) : "This does not work in append mode.";
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("countindels") || a.equals("indels")){
-				COUNT_INDELS=Tools.parseBoolean(b);
+				COUNT_INDELS=Parse.parseBoolean(b);
 			}else if(a.equals("callvariants") || a.equals("callvars") || a.equals("callvariations")){
-				callVariants=Tools.parseBoolean(b);
+				callVariants=Parse.parseBoolean(b);
 			}else if(a.equals("writematrices") || a.equals("write") || a.equals("wm")){
-				writeMatrices=Tools.parseBoolean(b);
+				writeMatrices=Parse.parseBoolean(b);
 			}else if(a.equals("ss") || a.equals("samstreamer")){
 				if(b!=null && Tools.isDigit(b.charAt(0))){
 					useStreamer=true;
 					streamerThreads=Tools.max(1, Integer.parseInt(b));
 				}else{
-					useStreamer=Tools.parseBoolean(b);
+					useStreamer=Parse.parseBoolean(b);
 				}
 			}else if(a.equals("passes") || a.equals("recalpasses")){
 				passes=Integer.parseInt(b);
@@ -163,9 +164,9 @@ public class CalcTrueQuality {
 			}else if(a.equals("ref")){
 				ref=b;
 			}else if(a.equals("realign")){
-				realign=Tools.parseBoolean(b);
+				realign=Parse.parseBoolean(b);
 			}else if(a.equals("prefilter")){
-				prefilter=Tools.parseBoolean(b);
+				prefilter=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("vars") || a.equals("variants") || a.equals("variations") || a.equals("varfile") || a.equals("inv")){
