@@ -17,6 +17,7 @@ import kmer.HashArray1D;
 import kmer.HashForest;
 import kmer.KmerTable;
 import kmer.ScheduleMaker;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -76,9 +77,9 @@ public class CalcUniqueness {
 			if(parser.parse(arg, a, b)){
 				//do nothing
 			}else if(a.equals("printlastbin") || a.equals("plb")){
-				printLastBin=Tools.parseBoolean(b);
+				printLastBin=Parse.parseBoolean(b);
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
@@ -86,21 +87,21 @@ public class CalcUniqueness {
 				ConcurrentGenericReadInputStream.verbose=verbose;
 				ReadWrite.verbose=verbose;
 			}else if(a.equals("cumulative")){
-				cumulative=Tools.parseBoolean(b);
+				cumulative=Parse.parseBoolean(b);
 			}else if(a.equals("offset")){
 				singleOffset=Integer.parseInt(b);
 			}else if(a.equals("percent") || a.equals("percents")){
-				showPercents=Tools.parseBoolean(b);
+				showPercents=Parse.parseBoolean(b);
 			}else if(a.equals("count") || a.equals("counts")){
-				showCounts=Tools.parseBoolean(b);
+				showCounts=Parse.parseBoolean(b);
 			}else if(a.equals("minprob") || a.equals("percents")){
 				minprob=Float.parseFloat(b);
 			}else if(a.equals("k")){
 				k_=Integer.parseInt(b);
 			}else if(a.equals("fixpeaks") || a.equals("fixspikes") || a.equals("fs")){
-				fixSpikes=Tools.parseBoolean(b);
+				fixSpikes=Parse.parseBoolean(b);
 			}else if(a.equals("bin") || a.equals("interval")){
-				interval=Tools.parseKMG(b);
+				interval=Parse.parseKMG(b);
 			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
 				parser.in1=arg;
 			}else{
