@@ -14,6 +14,7 @@ import aligner.SingleStateAlignerFlat2_1D;
 import dna.AminoAcid;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -68,25 +69,25 @@ public class FindPrimers implements Accumulator<FindPrimers.ProcessThread> {
 			String b=split.length>1 ? split[1] : null;
 
 			if(a.equals("rcomp")){
-				rcomp=Tools.parseBoolean(b);
+				rcomp=Parse.parseBoolean(b);
 			}else if(a.equals("usemsa2") || a.equals("msa2")){
-				useMSA2=Tools.parseBoolean(b);
+				useMSA2=Parse.parseBoolean(b);
 			}else if(a.equals("usessa2") || a.equals("ssa2")){
-				useSSA2=Tools.parseBoolean(b);
+				useSSA2=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("usessa1d") || a.equalsIgnoreCase("ssa1d")){
-				useSSA1D=Tools.parseBoolean(b);
+				useSSA1D=Parse.parseBoolean(b);
 			}else if(a.equals("swap")){
-				swapQuery=Tools.parseBoolean(b);
+				swapQuery=Parse.parseBoolean(b);
 			}else if(a.equals("printzeros")){
-				printZeros=Tools.parseBoolean(b);
+				printZeros=Parse.parseBoolean(b);
 			}else if(a.equals("twocolumn") || a.equals("2column")){
-				oneColumn=!Tools.parseBoolean(b);
+				oneColumn=!Parse.parseBoolean(b);
 			}else if(a.equals("onecolumn")){
-				oneColumn=Tools.parseBoolean(b);
+				oneColumn=Parse.parseBoolean(b);
 			}else if(a.equals("addr")){
-				addR=Tools.parseBoolean(b);
+				addR=Parse.parseBoolean(b);
 			}else if(a.equals("replicate") || a.equals("expand")){
-				replicateAmbiguous=Tools.parseBoolean(b);
+				replicateAmbiguous=Parse.parseBoolean(b);
 			}else if(a.equals("literal")){
 				literal_=b;
 			}else if(a.equals("cutoff") || a.equals("minid")){
