@@ -7,6 +7,7 @@ import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.KillSwitch;
 import shared.MetadataWriter;
 import shared.Parse;
 import shared.Parser;
@@ -401,7 +402,12 @@ public class FungalRelease {
 	 *         discarded.
 	 */
 	boolean processRead(final Read r1) {
-		assert (!banIupac || !r1.containsNonACGTN()) : "Non-ACGTN base found in scaffold " + r1.id;
+		//assert (!banIupac || !r1.containsNonACGTN()) : "Non-ACGTN base found in scaffold " + r1.id;
+		if(banIupac){
+			if(r1.containsNonACGTN()){
+				KillSwitch.exceptionKill(new RuntimeException("Non-ACGTN base found in scaffold " + r1.id));
+			}
+		}
 		r1.inflateGaps(minGapIn, minGapOut);
 		return r1.length() >= minScaf;
 	}
