@@ -14,6 +14,7 @@ import fileIO.ReadWrite;
 import json.JsonObject;
 import json.JsonParser;
 import server.ServerTools;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -103,12 +104,12 @@ public class GatherKapaStats {
 				maxLines=Long.parseLong(b);
 				if(maxLines<0){maxLines=Long.MAX_VALUE;}
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 //				ByteFile1.verbose=verbose;
 //				ByteFile2.verbose=verbose;
 //				ReadWrite.verbose=verbose;
 			}else if(a.equals("raw") || a.equals("printraw")){
-				printRaw=Tools.parseBoolean(b);
+				printRaw=Parse.parseBoolean(b);
 			}else if(parser.parse(arg, a, b)){
 				//do nothing
 			}else{
