@@ -11,6 +11,7 @@ import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextStreamWriter;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -84,7 +85,7 @@ public class KmerCountMulti {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("k")){
 				assert(b!=null) : "Bad parameter: "+arg;
 				String[] split2=b.split(",");
@@ -94,9 +95,9 @@ public class KmerCountMulti {
 			}else if(a.equals("ways") || a.equals("hashes")){
 				ways=Integer.parseInt(b);
 			}else if(a.equals("showstdev") || a.equals("showstddev") || a.equals("stdev") || a.equals("stddev")){
-				showStdev=Tools.parseBoolean(b);
+				showStdev=Parse.parseBoolean(b);
 			}else if(a.equals("wavg")){
-				useWavg=Tools.parseBoolean(b);
+				useWavg=Parse.parseBoolean(b);
 			}else if(a.equals("seed")){
 				parser.parse(null, "loglogseed", b);
 			}else if(a.equals("buckets")){
@@ -113,7 +114,7 @@ public class KmerCountMulti {
 					parser.loglogKlist.add(k);
 				}
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
