@@ -8,6 +8,7 @@ import dna.AminoAcid;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -73,13 +74,13 @@ public class MutateGenome {
 				indelRate=Float.parseFloat(b);
 				if(indelRate>1){indelRate/=100;}
 			}else if(a.equals("maxindel")){
-				maxIndel=Tools.parseIntKMG(b);
+				maxIndel=Parse.parseIntKMG(b);
 			}else if(a.equals("indelspacing")){
-				indelSpacing=Tools.parseIntKMG(b);
+				indelSpacing=Parse.parseIntKMG(b);
 			}else if(a.equals("seed")){
 				seed=Long.parseLong(b);
 			}else if(a.equals("nohomopolymers") || a.equals("nohomo") || a.equals("banhomopolymers") || a.equals("banhomo")){
-				banHomopolymers=Tools.parseBoolean(b);
+				banHomopolymers=Parse.parseBoolean(b);
 			}else if(a.equals("prefix")){
 				prefix=b;
 			}else if(a.equals("vcf") || a.equals("outvcf") || a.equals("vcfout") || a.equals("vars") || a.equals("varsout") || a.equals("outvars")){
