@@ -9,6 +9,7 @@ import dna.AminoAcid;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -70,15 +71,15 @@ public class MutateGenome2 {
 				indelRate=Float.parseFloat(b);
 				if(indelRate>1){indelRate/=100;}
 			}else if(a.equals("maxindel")){
-				maxIndel=Tools.parseIntKMG(b);
+				maxIndel=Parse.parseIntKMG(b);
 			}else if(a.equals("indelspacing")){
-				indelSpacing=Tools.parseIntKMG(b);
+				indelSpacing=Parse.parseIntKMG(b);
 			}else if(a.equals("seed")){
 				seed=Long.parseLong(b);
 			}else if(a.equals("ploidy")){
 				ploidy=Integer.parseInt(b);
 			}else if(a.equals("nohomopolymers") || a.equals("nohomo") || a.equals("banhomopolymers") || a.equals("banhomo")){
-				banHomopolymers=Tools.parseBoolean(b);
+				banHomopolymers=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("hetrate")){
 				hetRate=Float.parseFloat(b);
 			}else if(a.equals("prefix")){
