@@ -48,6 +48,9 @@ public class RQCFilterStats {
 	long readsMitoMap;
 	long basesMitoMap;
 
+	long readsSipMap;
+	long basesSipMap;
+
 	long readsRiboKmer;
 	long basesRiboKmer;
 
@@ -74,13 +77,13 @@ public class RQCFilterStats {
 	long totalReadsRemoved(){
 		return readsLowQuality/*+readsN*/+readsArtifact/*+readsFTrimmed*/
 				+readsAdapter+readsSpikin+readsDuplicate
-				+readsRiboMap+readsChloroMap+readsMitoMap+readsRiboKmer
+				+readsRiboMap+readsChloroMap+readsMitoMap+readsSipMap+readsRiboKmer
 				+readsMouse+readsCat+readsDog+readsHuman+readsMicrobe+readsOther;
 	}
 	long totalBasesRemoved(){
 		return basesLowQuality/*+basesN*/+basesArtifact+basesFTrimmed
 				+basesAdapter+basesSpikin+basesDuplicate
-				+basesRiboMap+basesChloroMap+basesMitoMap+basesRiboKmer
+				+basesRiboMap+basesChloroMap+basesMitoMap+basesSipMap+basesRiboKmer
 				+basesMouse+basesCat+basesDog+basesHuman+basesMicrobe+basesOther;
 	}
 	
@@ -92,7 +95,7 @@ public class RQCFilterStats {
 	public String toString(boolean skipAssertion){
 		assert(skipAssertion || readsIn>=readsOut) : toString(true);
 		assert(skipAssertion || basesIn>=basesOut) : toString(true);
-		assert(skipAssertion || readsIn-totalReadsRemoved()==readsOut) : toString(true)+", "+totalReadsRemoved();
+		assert(skipAssertion || readsIn-totalReadsRemoved()==readsOut) : toString(true)+"\n\ntrr="+totalReadsRemoved()+"\nri="+readsIn+"\nro="+readsOut;
 		assert(skipAssertion || basesIn-totalBasesRemoved()==basesOut) : toString(true)+"\n"+basesIn+"-"+totalBasesRemoved()+"!="+basesOut;
 		StringBuilder sb=new StringBuilder(1000);
 		sb.append("#Class\tReads\tBases\tReadPct\tBasePct\tNotes\n");
@@ -106,6 +109,7 @@ public class RQCFilterStats {
 		sb.append(format("Spike-in", readsSpikin, basesSpikin, readsIn, basesIn));
 		sb.append(format("ForceTrim", /*readsFTrimmed*/0, basesFTrimmed, readsIn, basesIn));
 		sb.append(format("Adapter", readsAdapter, basesAdapter, readsIn, basesIn));
+		sb.append(format("SipMap", readsSipMap, basesSipMap, readsIn, basesIn));
 		sb.append(format("ChloroMap", readsChloroMap, basesChloroMap, readsIn, basesIn));
 		sb.append(format("MitoMap", readsMitoMap, basesMitoMap, readsIn, basesIn));
 		sb.append(format("RiboMap", readsRiboMap, basesRiboMap, readsIn, basesIn));
@@ -210,6 +214,24 @@ public class RQCFilterStats {
 		tf.close();
 	}
 	
+	void parseSip(String fname){
+		if(fname==null){return;}
+		TextFile tf=new TextFile(fname);
+		for(String line=tf.nextLine(); line!=null; line=tf.nextLine()){
+			if(!line.startsWith("#")){
+				long[] ret=parseStatsLine(line);
+				if(true){
+					readsSipMap+=ret[0];
+					basesSipMap+=ret[1];
+				}else{
+					readsOther+=ret[0];
+					basesOther+=ret[1];
+				}
+			}
+		}
+		tf.close();
+	}
+	
 //	//Ribo:
 //	tid|39138|lcl|SSU_GQ398331.1.1377 Bacteria;Proteobacteria;Gammaproteobacteria;Enterobacteriales;Enterobacteriaceae;Enterobacter;bacterium A1(2009)
 //	//Chloro:
