@@ -4,9 +4,10 @@ import java.io.PrintStream;
 import java.util.Random;
 
 import dna.AminoAcid;
+import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
-import fileIO.ByteStreamWriter;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -55,20 +56,22 @@ public class RandomGenome {
 			if(b!=null && b.equalsIgnoreCase("null")){b=null;}
 
 			if(a.equals("chroms")){
-				chroms=Tools.parseIntKMG(b);
+				chroms=Parse.parseIntKMG(b);
 			}else if(a.equals("len") || a.equals("length") || a.equals("size")){
-				totalLength=Tools.parseKMG(b);
+				totalLength=Parse.parseKMG(b);
 			}else if(a.equals("pad")){
-				pad=Tools.max(0, Tools.parseIntKMG(b));
+				pad=Tools.max(0, Parse.parseIntKMG(b));
 			}else if(a.equals("gc")){
 				gc=Float.parseFloat(b);
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ReadWrite.verbose=verbose;
 			}else if(a.equals("nohomopolymers") || a.equals("banhomopolymers") || a.equals("nopoly")){
-				noPoly=Tools.parseBoolean(b);
+				noPoly=Parse.parseBoolean(b);
 			}else if(a.equals("includestop") || a.equals("stop")){
-				includeStop=Tools.parseBoolean(b);
+				includeStop=Parse.parseBoolean(b);
+			}else if(a.equals("seed")){
+				seed=Long.parseLong(b);
 			}else if(parser.parse(arg, a, b)){
 				//do nothing
 			}else{
@@ -100,6 +103,8 @@ public class RandomGenome {
 		}
 
 		ffout=FileFormat.testOutput(out, FileFormat.FA, null, true, overwrite, append, false);
+		
+		randy=Shared.threadLocalRandom(seed);
 	}
 	
 	void process(Timer t){
@@ -116,7 +121,7 @@ public class RandomGenome {
 		bsw.start();
 		
 		for(int chrom=1; chrom<=chroms; chrom++){
-			bsw.print('>').println(chrom);
+			bsw.print('>').print("contig").println(chrom);
 			ByteBuilder bb=new ByteBuilder(wrap+1);
 			byte prev='N';
 			final int max=chromLength+2*pad;
@@ -178,7 +183,7 @@ public class RandomGenome {
 		final byte[] acids=AminoAcid.numberToAcid;
 		final int limit=(includeStop ? acids.length : acids.length-1);
 		for(int chrom=1; chrom<=chroms; chrom++){
-			bsw.print('>').println(chrom);
+			bsw.print('>').print("gene").println(chrom);
 			ByteBuilder bb=new ByteBuilder(wrap+1);
 			byte prev='X';
 			final int max=chromLength+2*pad;
@@ -215,10 +220,11 @@ public class RandomGenome {
 	int pad=0;
 	boolean noPoly=false;
 	boolean includeStop=false;
+	long seed=-1;
 	
 	/*--------------------------------------------------------------*/
 
-	Random randy=Shared.threadLocalRandom();
+	final Random randy;
 	
 	private long linesOut=0;
 	private long bytesOut=0;
