@@ -17,6 +17,7 @@ import dna.AminoAcid;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextStreamWriter;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -129,16 +130,16 @@ public class ReadKmerDepthDistribution {
 				assert(matrixbits<63);
 				cells=1L<<matrixbits;
 			}else if(a.startsWith("cells")){
-				cells=Tools.parseKMG(b);
+				cells=Parse.parseKMG(b);
 			}else if(a.startsWith("precells") || a.startsWith("prefiltercells")){
-				precells=Tools.parseKMG(b);
+				precells=Parse.parseKMG(b);
 				prefilter=prefilter || precells!=0;
 			}else if(a.startsWith("minq")){
 				minq=Byte.parseByte(b);
 			}else if(a.equals("zerobin")){
-				ZERO_BIN=Tools.parseBoolean(b);
+				ZERO_BIN=Parse.parseBoolean(b);
 			}else if(a.equals("deterministic") || a.equals("dr")){
-				boolean x=Tools.parseBoolean(b);
+				boolean x=Parse.parseBoolean(b);
 				deterministic=x;
 			}else if(a.startsWith("minprob")){
 				KmerCountAbstract.minProb=Float.parseFloat(b);
@@ -148,7 +149,7 @@ public class ReadKmerDepthDistribution {
 				prehashes=Integer.parseInt(b);
 				prefilter=prefilter || prehashes!=0;
 			}else if(a.equals("prefilter")){
-				prefilter=Tools.parseBoolean(b);
+				prefilter=Parse.parseBoolean(b);
 			}else if(a.startsWith("stepsize") || a.startsWith("buildstepsize")){
 				buildStepsize=Integer.parseInt(b);
 			}else if(a.startsWith("passes") || a.startsWith("buildpasses")){
@@ -158,31 +159,31 @@ public class ReadKmerDepthDistribution {
 			}else if(a.equals("threads") || a.equals("t")){
 				threads=Integer.parseInt(b);
 			}else if(a.equals("reads") || a.startsWith("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.startsWith("tablereads") || a.startsWith("buildreads")){
-				tablereads=Tools.parseKMG(b);
+				tablereads=Parse.parseKMG(b);
 			}else if(a.equals("out") || a.equals("outk") || a.equals("outkeep") || a.equals("outgood")){
 				outKeep=b;
 			}else if(a.startsWith("hist")){
 				histFile=b;
 			}else if(a.startsWith("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ordered") || a.equals("ord")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 			}else if(a.equals("auto") || a.equals("automatic")){
-				auto=Tools.parseBoolean(b);
+				auto=Parse.parseBoolean(b);
 			}else if(a.equals("canonical")){
-				CANONICAL=KmerCountAbstract.CANONICAL=Tools.parseBoolean(b);
+				CANONICAL=KmerCountAbstract.CANONICAL=Parse.parseBoolean(b);
 			}else if(a.equals("fixspikes")){
-				FIX_SPIKES=Tools.parseBoolean(b);
+				FIX_SPIKES=Parse.parseBoolean(b);
 			}else if(a.equals("printzerocoverage") || a.equals("pzc")){
-				PRINT_ZERO_COVERAGE=Tools.parseBoolean(b);
+				PRINT_ZERO_COVERAGE=Parse.parseBoolean(b);
 			}else if(a.equals("removeduplicatekmers") || a.equals("rdk")){
-				KmerCountAbstract.KEEP_DUPLICATE_KMERS=!Tools.parseBoolean(b);
+				KmerCountAbstract.KEEP_DUPLICATE_KMERS=!Parse.parseBoolean(b);
 			}else if(a.equals("target") || a.equals("targetdepth")){
 				TARGET_DEPTH=Integer.parseInt(b);
 			}else if(a.equals("max") || a.equals("maxdepth")){
