@@ -1,5 +1,6 @@
 package jgi;
 
+import java.io.File;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -17,6 +18,7 @@ import fileIO.TextStreamWriter;
 import json.JsonObject;
 import json.JsonParser;
 import server.ServerTools;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -72,6 +74,7 @@ public class TestFormat {
 		Read.NULLIFY_BROKEN_QUALITY=true;
 		ReadWrite.USE_PIGZ=ReadWrite.USE_UNPIGZ=true;
 		SketchObject.defaultParams.minProb=0;
+		FileFormat.PRINT_WARNING=false;
 		
 		Parser parser=new Parser();
 		for(int i=0; i<args.length; i++){
@@ -83,15 +86,15 @@ public class TestFormat {
 			if(a.equals("parse_flag_goes_here")){
 				//Set a variable here
 			}else if(a.equals("full")){
-				full=Tools.parseBoolean(b);
+				full=Parse.parseBoolean(b);
 			}else if(a.equals("in") || a.equals("in1")){
 				in.add(b);
 			}else if(a.equals("sketchsize")){
-				sketchSize=Tools.parseIntKMG(b);
+				sketchSize=Parse.parseIntKMG(b);
 			}
 			
 			else if(a.equalsIgnoreCase("parseZmw") || a.equals("zmw") || a.equals("zmws")){
-				parseZmw=Tools.parseBoolean(b);
+				parseZmw=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("barcodes") || a.equals("barcodefile")){
@@ -100,7 +103,7 @@ public class TestFormat {
 			
 			
 			else if(a.equals("hist") || a.equals("hists")){
-				if(!Tools.parseBoolean(b)){
+				if(!Parse.parseBoolean(b)){
 					qhistFile=ihistFile=khistFile=bhistFile=lhistFile=gchistFile=zmwhistFile=null;
 				}
 			}else if(a.equals("qhist") || a.equals("qhistfile")){
@@ -120,7 +123,7 @@ public class TestFormat {
 //					forceMakeBhist=true;
 				}
 			}else if(a.equals("maxbhistlen") || a.equals("bhistlen")){
-				maxBhistLen=Tools.parseIntKMG(b);
+				maxBhistLen=Parse.parseIntKMG(b);
 			}else if(a.equals("lhist") || a.equals("lhistfile")){
 				lhistFile=b;
 			}else if(a.equals("zmwhist") || a.equals("zmwhistfile")){
@@ -130,25 +133,25 @@ public class TestFormat {
 			}else if(a.equals("junk") || a.equals("junkfile")){
 				junkFile=b;
 			}else if(a.equalsIgnoreCase("printBarcodes")){
-				printBarcodes=Tools.parseBoolean(b);
+				printBarcodes=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("printQhist")){
-				printQhist=Tools.parseBoolean(b);
+				printQhist=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("printIhist")){
-				printIhist=Tools.parseBoolean(b);
+				printIhist=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("printJunk") || a.equals("junk")){
-				printJunk=Tools.parseBoolean(b);
+				printJunk=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("printSpeed") || a.equals("speed")){
-				printSpeed=Tools.parseBoolean(b);
+				printSpeed=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("fast")){
-				fast=Tools.parseBoolean(b);
+				fast=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("slow")){
-				fast=!Tools.parseBoolean(b);
+				fast=!Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("sketch") || a.equalsIgnoreCase("card")){
-				makeSketch=Tools.parseBoolean(b);
+				makeSketch=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("merge")){
-				doMerge=Tools.parseBoolean(b);
+				doMerge=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("trim")){
-				doTrim=Tools.parseBoolean(b);
+				doTrim=Parse.parseBoolean(b);
 			}
 			
 			else if(parser.parse(arg, a, b)){
@@ -167,7 +170,7 @@ public class TestFormat {
 			maxReads=parser.maxReads;
 			makeSketch=(makeSketch || parser.loglog);
 			SketchObject.targetSketchSize=sketchSize;
-//			loglog=(parser.loglog ? new LogLog(parser) : null);
+//			loglog=(parser.loglog ? CardinalityTracker.makeTracker(parser) : null);
 		}
 //		assert(false) : sketch+", "+parser.loglog;
 		if(makeSketch){
@@ -218,10 +221,14 @@ public class TestFormat {
 				}else if(ff.vcf()){
 					variant=true;
 					loadVcf(ff);
+				}else{
+					System.err.println("Does not seem to be a sequence or variant format: "+ff.rawExtension());
 				}
 			}
+//			System.err.println(ff);
 		}
 		
+		
 		if(sequence){
 			printSequenceResults();
 		}else if(variant){
@@ -354,14 +361,25 @@ public class TestFormat {
 //			System.err.println(smm.pacBioDetected);
 			println("Cardinality\t"+(sketch==null ? 0 : sketch.genomeSizeEstimate()));
 			if(khistFile!=null){
-				ArrayList<LongPair> list=sketch.toKhist();
-				ByteStreamWriter bsw=new ByteStreamWriter(khistFile, true, false, false);
-				bsw.start();
-				bsw.println("#Depth\tCount");
-				for(LongPair lp : list){
-					bsw.print(lp.a).print('\t').print(lp.b).nl();
+				if(sketch!=null){
+					ArrayList<LongPair> list=sketch.toKhist();
+					ByteStreamWriter bsw=new ByteStreamWriter(khistFile, true, false, false);
+					bsw.start();
+					bsw.println("#Depth\tCount");
+					for(LongPair lp : list){
+						bsw.print(lp.a).print('\t').print(lp.b).nl();
+					}
+					bsw.poisonAndWait();
+				}else{
+					try {
+						if(!FileFormat.isStdio(khistFile) && new File(khistFile).exists()){
+							new File(khistFile).delete();
+						}
+					} catch (Exception e) {
+						// TODO Auto-generated catch block
+						e.printStackTrace();
+					}
 				}
-				bsw.poisonAndWait();
 			}
 			if(zmwhistFile!=null){
 				if(parseZmw && zmwMap.size()>0){
@@ -936,7 +954,7 @@ public class TestFormat {
 				assert((ff==null || ff.samOrBam()) || (r.mate!=null)==cris.paired());
 				if(parseZmw) {
 					try {
-						int zmw=Tools.parseZmw(r.id);
+						int zmw=Parse.parseZmw(r.id);
 						parseZmwT=(zmw>=0 && zmw<=1000000000);
 					} catch (Exception e) {}
 				}
@@ -1010,7 +1028,7 @@ public class TestFormat {
 			if(parseZmwT && r.pairnum()==0){
 				int zmw=-1;
 				try {
-					zmw=Tools.parseZmw(r.id);
+					zmw=Parse.parseZmw(r.id);
 				} catch (Exception e) {
 					// TODO Auto-generated catch block
 					e.printStackTrace();
