@@ -289,7 +289,7 @@ public abstract class AbstractKmerTable {
 		return sb;
 	}
 	
-	public static final ByteBuilder toBytes(long kmer, int count, int k, ByteBuilder bb){
+	public static final ByteBuilder toBytes(long kmer, long count, int k, ByteBuilder bb){
 		byte[] lookup=(Shared.AMINO_IN ? AminoAcid.numberToAcid : AminoAcid.numberToBase);
 		int bits=(Shared.AMINO_IN ? 5 : 2);
 		int mask=(Shared.AMINO_IN ? 31 : 3);
