@@ -326,6 +326,10 @@ public final class HashArray1D extends HashArray {
 		return Arrays.toString(array);
 	}
 	
+	public Walker walk(){
+		return new Walker1D();
+	}
+	
 	/*--------------------------------------------------------------*/
 	/*----------------            Fields            ----------------*/
 	/*--------------------------------------------------------------*/
@@ -334,6 +338,62 @@ public final class HashArray1D extends HashArray {
 	
 	public int[] values(){return values;}
 	
+	/*--------------------------------------------------------------*/
+	/*----------------            Walker            ----------------*/
+	/*--------------------------------------------------------------*/
+	
+	public class Walker1D extends Walker {
+		
+		Walker1D(){
+			ha=HashArray1D.this;
+			victims=ha.victims().toList();
+		}
+		
+		/** 
+		 * Fills this object with the next key and value.
+		 * @return True if successful.
+		 */
+		public boolean next(){
+			while(i<values.length && values[i]==NOT_XPRESENT){i++;}
+			if(i<values.length){
+				kmer=array[i];
+				value=values[i];
+				assert(value!=NOT_XPRESENT);
+				i++;
+				return true;
+			}
+			if(i2<victims.size()){
+				KmerNode kn=victims.get(i2);
+				kmer=kn.pivot;
+				value=kn.value();
+				assert(value!=NOT_XPRESENT);
+				i2++;
+				return true;
+			}
+			kmer=-1;
+			value=NOT_XPRESENT;
+			return false;
+		}
+		
+		public long kmer(){return kmer;}
+		public int value(){return value;}
+		
+		/** Hash map over which this is walking */
+		private HashArray1D ha;
+		/** Victim list of the hash map */
+		private ArrayList<KmerNode> victims;
+		
+		private long kmer;
+		private int value;
+
+		/** Potential next kmer cell; may point to an empty cell */
+		private int i=0;
+		/** Next victim in list */
+		private int i2=0;
+	}
+	
+	//TODO: Remove after fixing array initialization
+	private static final int NOT_XPRESENT=0;
 
 	
 }
