@@ -658,7 +658,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 
 				//Update kmers
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 
 				if(minProb2>0 && quals!=null){//Update probability
 					prob=prob*PROB_CORRECT[quals[i]];
@@ -715,7 +715,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 
 				//Update kmers
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 
 				if(minProb>0 && quals!=null){//Update probability
 					prob=prob*PROB_CORRECT[quals[i]];
@@ -788,7 +788,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 			final long x=AminoAcid.baseToNumber[b];
 			final long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			if(x<0){
 				len=0;
 				kmer=rkmer=0;
@@ -830,7 +830,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 			final long x=AminoAcid.baseToNumber[base];
 			final long x2=AminoAcid.baseToComplementNumber[base];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			
 			if(x<0){
 				len=0;
@@ -872,7 +872,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 			final long x=AminoAcid.baseToNumber[base];
 			final long x2=AminoAcid.baseToComplementNumber[base];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			
 			if(x<0){
 				len=0;
@@ -921,7 +921,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 			final long x=AminoAcid.baseToNumber[base];
 			final long x2=AminoAcid.baseToComplementNumber[base];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			
 			if(x<0){
 				len=0;
@@ -1061,7 +1061,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 				final long x=AminoAcid.baseToNumber[b];
 				final long x2=AminoAcid.baseToComplementNumber[b];
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				if(x<0){
 					len=0;
 					kmer=rkmer=0;
@@ -1095,7 +1095,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 				final long x=AminoAcid.baseToNumber[b];
 				final long x2=AminoAcid.baseToComplementNumber[b];
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				if(x<0){
 					len=0;
 					kmer=rkmer=0;
@@ -1142,7 +1142,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 			final long x=AminoAcid.baseToNumber[b];
 			final long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			if(x<0){
 				len=0;
 				kmer=rkmer=0;
@@ -1175,7 +1175,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 			final long x=AminoAcid.baseToNumber[b];
 			final long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			if(x<0){
 				len=0;
 				kmer=rkmer=0;
@@ -1208,7 +1208,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 			final long x=AminoAcid.baseToNumber[b];
 			final long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			if(x<0){
 				len=0;
 				kmer=rkmer=0;
@@ -1255,7 +1255,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 			final long x=AminoAcid.baseToNumber[b];
 			final long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			if(x<0){
 				len=0;
 				kmer=rkmer=0;
@@ -1297,7 +1297,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 			final long x=AminoAcid.baseToNumber[b];
 			final long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			if(x<0){
 				len=0;
 				kmer=rkmer=0;
