@@ -5,8 +5,8 @@ import java.io.File;
 import dna.Data;
 import fileIO.ReadWrite;
 import fileIO.TextFile;
+import shared.Parse;
 import shared.Shared;
-import shared.Tools;
 
 /**
  * @author Brian Bushnell
@@ -131,7 +131,7 @@ public class MakePacBioScript {
 			}else if(a.equals("mode")){
 				mode=b;
 			}else if(a.startsWith("reads") || a.startsWith("maxreads") || a.equals("rd")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.startsWith("build") || a.startsWith("genome") || a.equals("b")){
 				build=Integer.parseInt(b);
 				String s=Data.chromFname(1, build);
@@ -199,9 +199,9 @@ public class MakePacBioScript {
 				output=b;
 				if((new File(b)).exists()){System.out.println("Warning! Outfile already exists: "+b);}
 			}else if(a.startsWith("ecc")){
-				ecc=Tools.parseBoolean(b);
+				ecc=Parse.parseBoolean(b);
 			}else if(a.equals("sort")){
-				sort=Tools.parseBoolean(b);
+				sort=Parse.parseBoolean(b);
 			}else{
 				throw new RuntimeException("Unknown parameter "+args[i]);
 			}
