@@ -10,6 +10,7 @@ import dna.Data;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -68,7 +69,7 @@ public class RemoveAdapters2 {
 			}else if(a.equals("path") || a.equals("root") || a.equals("tempdir")){
 				Data.setPath(b);
 			}else if(a.equals("usealtmsa")){
-				USE_ALT_MSA=Tools.parseBoolean(b);
+				USE_ALT_MSA=Parse.parseBoolean(b);
 			}else if(a.equals("fasta") || a.equals("in") || a.equals("input") || a.equals("in1") || a.equals("input1")){
 				in1=b;
 				if(b.indexOf('#')>-1){
@@ -80,26 +81,26 @@ public class RemoveAdapters2 {
 			}else if(a.equals("query") || a.equals("adapter")){
 				query=b;
 			}else if(a.equals("split")){
-				splitReads=Tools.parseBoolean(b);
+				splitReads=Parse.parseBoolean(b);
 			}else if(a.equals("plusonly")){
-				boolean x=Tools.parseBoolean(b);
+				boolean x=Parse.parseBoolean(b);
 				if(x){TRY_PLUS=true; TRY_MINUS=false;}
 			}else if(a.equals("minusonly")){
-				boolean x=Tools.parseBoolean(b);
+				boolean x=Parse.parseBoolean(b);
 				if(x){TRY_PLUS=false; TRY_MINUS=true;}
 			}else if(a.startsWith("mincontig")){
 				minContig=Integer.parseInt(b);
 			}else if(a.equals("append") || a.equals("app")){
-				append=ReadStats.append=Tools.parseBoolean(b);
+				append=ReadStats.append=Parse.parseBoolean(b);
 			}else if(a.equals("overwrite") || a.equals("ow")){
-				overwrite=Tools.parseBoolean(b);
+				overwrite=Parse.parseBoolean(b);
 				System.out.println("Set overwrite to "+overwrite);
 			}else if(a.equals("threads") || a.equals("t")){
 				if(b.equalsIgnoreCase("auto")){THREADS=Shared.LOGICAL_PROCESSORS;}
 				else{THREADS=Integer.parseInt(b);}
 				System.out.println("Set threads to "+THREADS);
 			}else if(a.equals("reads") || a.equals("maxreads")){
-				maxReads=Tools.parseKMG(b);
+				maxReads=Parse.parseKMG(b);
 			}else if(a.startsWith("outname") || a.startsWith("outfile") || a.equals("out")){
 				if(b==null || b.equalsIgnoreCase("null") || b.equalsIgnoreCase("none") || split.length==1){
 					System.out.println("No output file.");
@@ -120,7 +121,7 @@ public class RemoveAdapters2 {
 			}else if(a.equals("suspectratio")){
 				SUSPECT_RATIO=Float.parseFloat(b);
 			}else if(a.startsWith("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else{
 				throw new RuntimeException("Unknown parameter: "+args[i]);
 			}
