@@ -9,11 +9,12 @@ import aligner.SingleStateAlignerFlat2;
 import aligner.SingleStateAlignerFlat3;
 import aligner.SingleStateAlignerFlatFloat;
 import dna.AminoAcid;
+import shared.KillSwitch;
 import shared.Tools;
 import stream.Read;
 import structures.FloatList;
-import structures.LongHashSet;
 import structures.IntList;
+import structures.LongHashSet;
 
 
 /**
@@ -225,13 +226,13 @@ public class GeneCaller extends ProkObject {
 			orf.pathScoreMinus=-999999;
 		}
 		
-		int[] lastPositionScored=new int[6];
+		int[] lastPositionScored=KillSwitch.allocInt1D(6);
 		Arrays.fill(lastPositionScored, -1);
 
 		//Index of highest-scoring ORF in this frame, with prev on the plus strand
-		int[] bestIndexPlus=new int[6];
+		int[] bestIndexPlus=KillSwitch.allocInt1D(6);
 		//Index of highest-scoring ORF in this frame, with prev on the minus strand
-		int[] bestIndexMinus=new int[6];
+		int[] bestIndexMinus=KillSwitch.allocInt1D(6);
 		//Highest-scoring ORF in this frame, with prev on the plus strand
 		Orf[] bestOrfPlus=new Orf[6];
 		//Highest-scoring ORF in this frame, with prev on the minus strand
