@@ -732,6 +732,8 @@ public class Parser {
 		}else if(a.equals("entropywindow") || a.equals("ew")){
 			EntropyTracker.defaultWindowBases=Integer.parseInt(b);
 			EntropyTracker.setDefaultWindow=true;
+		}else if(a.equalsIgnoreCase("protFull")){
+			TaxTree.protFull=true;
 		}
 		
 		else{
