@@ -13,6 +13,7 @@ import stream.SamLine;
 import structures.ByteBuilder;
 import structures.EntropyTracker;
 import structures.LongList;
+import structures.SuperLongList;
 
 
 /**
@@ -136,7 +137,7 @@ public class ReadStats {
 		}
 		
 		if(COLLECT_LENGTH_STATS){
-			lengthHist=new LongList(501);
+			lengthHist=new SuperLongList(20000);
 		}else{
 			lengthHist=null;
 		}
@@ -427,7 +428,7 @@ public class ReadStats {
 	
 	private void addToLengthHistogram(final Read r, int pairnum){
 		if(r==null || r.bases==null){return;}
-		int x=Tools.min(r.length(), MAXLENGTHLEN);
+		int x=r.length();//Tools.min(r.length(), MAXLENGTHLEN); Old style before SLL
 		lengthHist.increment(x, 1);
 	}
 	
@@ -463,8 +464,8 @@ public class ReadStats {
 		final Read r2=r1.mate;
 		final int len1=r1.length(), len2=r1.mateLength();
 		
-		final float entropy1=(len1>0 ? eTracker.averageEntropy(r1.bases, false) : -1);
-		final float entropy2=(len2>0 ? eTracker.averageEntropy(r2.bases, false) : -1);
+		final float entropy1=(len1>0 ? eTracker.averageEntropy(r1.bases, allowEntropyNs) : -1);
+		final float entropy2=(len2>0 ? eTracker.averageEntropy(r2.bases, allowEntropyNs) : -1);
 		if(/* usePairEntropy */ false){
 			final float entropy;
 			if(r2==null){
@@ -815,8 +816,11 @@ public class ReadStats {
 			if(IDENTITY_HIST_FILE!=null){rs.writeIdentityToFile(IDENTITY_HIST_FILE, true);}
 			if(TIME_HIST_FILE!=null){rs.writeTimeToFile(TIME_HIST_FILE);}
 			
-			return rs.errorState;
+			boolean b=rs.errorState;
+			clear();
+			return b;
 		}
+		clear();
 		return false;
 	}
 	
@@ -1319,6 +1323,49 @@ public class ReadStats {
 		errorState|=bsw.errorState;
 	}
 	
+	public void writeHistogramToFile(String fname, String header, SuperLongList hist, boolean printZeros){
+		ByteStreamWriter bsw=new ByteStreamWriter(fname, overwrite, false, false);
+		bsw.start();
+		bsw.print(header);
+		
+		hist.sort();
+		long max=hist.max();
+		long[] array=hist.array();
+		LongList list=hist.list();
+
+		ByteBuilder bb=new ByteBuilder(40);
+		for(int i=0; i<array.length; i++){
+			long x=array[i];
+			if(x>0 || printZeros){
+				bb.clear().append(i).tab().append(x).nl();
+				bsw.print(bb);
+			}
+		}
+		{//TODO: This part does not bother printing zeros regardless of the flag.
+			long prev=-1;
+			int streak=0;
+			for(int i=0; i<list.size(); i++){
+				long x=list.get(i);
+				if(x==prev){streak++;}
+				else{
+					if(streak>0){//Print previous key
+						bb.clear().append(prev).tab().append(streak).nl();
+						bsw.print(bb);
+					}
+					streak=1;
+					prev=x;
+				}
+			}
+			if(streak>0){//Print final key
+				bb.clear().append(prev).tab().append(streak).nl();
+				bsw.print(bb);
+			}
+		}
+		bsw.poison();
+		bsw.waitForFinish();
+		errorState|=bsw.errorState;
+	}
+	
 	public void writeGCToFile(String fname, boolean printZeros){
 		final long[] hist;
 		if(GC_BINS_AUTO && gcMaxReadLen+1<gcHist.length){
@@ -1516,7 +1563,7 @@ public class ReadStats {
 	/** Insert size */
 	public final LongList insertHist;
 	/** Read length */
-	public final LongList lengthHist;
+	public final SuperLongList lengthHist;
 	/** Number errors per read */
 	public final LongList errorHist;
 	/** Insertion length */
@@ -1530,7 +1577,8 @@ public class ReadStats {
 	
 	public static boolean REQUIRE_PROPER_PAIR=true;
 	public static int MAXLEN=6000;
-	public static int MAXINSERTLEN=40000;
+	public static int MAXINSERTLEN=80000;
+	@Deprecated
 	public static int MAXLENGTHLEN=80000;
 	public static final int MAXTIMELEN=80000;
 	public static final int MAXINSLEN=1000;
@@ -1560,6 +1608,38 @@ public class ReadStats {
 	
 //	public static double matedPercent=0;
 	
+	public static void clear(){
+		COLLECT_QUALITY_STATS=false;
+		COLLECT_QUALITY_ACCURACY=false;
+		COLLECT_MATCH_STATS=false;
+		COLLECT_INSERT_STATS=false;
+		COLLECT_BASE_STATS=false;
+		COLLECT_INDEL_STATS=false;
+		COLLECT_GC_STATS=false;
+		COLLECT_ENTROPY_STATS=false;
+		COLLECT_ERROR_STATS=false;
+		COLLECT_LENGTH_STATS=false;
+		COLLECT_IDENTITY_STATS=false;
+		COLLECT_TIME_STATS=false;
+		
+		AVG_QUAL_HIST_FILE=null;
+		QUAL_HIST_FILE=null;
+		BQUAL_HIST_FILE=null;
+		QUAL_COUNT_HIST_FILE=null;
+		BQUAL_HIST_OVERALL_FILE=null;
+		QUAL_ACCURACY_FILE=null;
+		MATCH_HIST_FILE=null;
+		INSERT_HIST_FILE=null;
+		BASE_HIST_FILE=null;
+		INDEL_HIST_FILE=null;
+		ERROR_HIST_FILE=null;
+		LENGTH_HIST_FILE=null;
+		GC_HIST_FILE=null;
+		ENTROPY_HIST_FILE=null;
+		IDENTITY_HIST_FILE=null;
+		TIME_HIST_FILE=null;
+	}
+	
 	public static ArrayList<ReadStats> objectList=new ArrayList<ReadStats>();
 	public static boolean COLLECT_QUALITY_STATS=false;
 	public static boolean COLLECT_QUALITY_ACCURACY=false;
@@ -1581,6 +1661,7 @@ public class ReadStats {
 	}
 	
 	public static boolean usePairGC=true;
+	public static boolean allowEntropyNs=true;
 	
 	public static String AVG_QUAL_HIST_FILE=null;
 	public static String QUAL_HIST_FILE=null;
