@@ -23,6 +23,7 @@ public class Shared {
 
 
 	public static boolean ENV=(System.getenv()!=null);
+	private static String HOSTNAME;
 	public static boolean WINDOWS=envContainsPair("OS", "Win", true);
 	public static boolean MAC=envContainsPair("OS", "Mac", true);
 	//https://stackoverflow.com/questions/14288185/detecting-windows-or-linux
@@ -33,8 +34,8 @@ public class Shared {
 	public static boolean CORI=envContainsPair("NERSC_HOST", "cori", false);
 	public static boolean NERSC=envContainsKey("NERSC_HOST");
 	public static boolean AWS=envContainsKey("EC2_HOME");
+	public static boolean IGBVM="taxonomy-vm".equals(HOSTNAME()) || "taxonomy-vm-2".equals(HOSTNAME());
 	public static boolean AMD64="amd64".equalsIgnoreCase(System.getProperty("os.arch"));
-	private static String HOSTNAME;
 
 	public static void setTaxServer(String path){
 		taxServerNersc=taxServerAws=path;
@@ -124,8 +125,8 @@ public class Shared {
 	public static final int GAPCOST=Tools.max(1, GAPLEN/64);
 	public static final byte GAPC='-';
 	
-	public static String BBMAP_VERSION_STRING="38.90";
-	public static String BBMAP_VERSION_NAME="Byte Safety";
+	public static String BBMAP_VERSION_STRING="38.95";
+	public static String BBMAP_VERSION_NAME="CFS Migration";
 	
 	public static boolean TRIM_READ_COMMENTS=false;
 	public static boolean TRIM_RNAME=false; //For mapped sam reads
