@@ -8,6 +8,7 @@ import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -116,40 +117,40 @@ public class AddSSU {
 				maxLines=Long.parseLong(b);
 				if(maxLines<0){maxLines=Long.MAX_VALUE;}
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 //				ByteFile1.verbose=verbose;
 //				ByteFile2.verbose=verbose;
 //				ReadWrite.verbose=verbose;
 			}
 			
 			else if(a.equalsIgnoreCase("preferSSUMap")){
-				preferSSUMap=Tools.parseBoolean(b);
+				preferSSUMap=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("preferSSUMapForEuks") || a.equalsIgnoreCase("preferSSUMapEuks")){
-				preferSSUMapEuks=Tools.parseBoolean(b);
+				preferSSUMapEuks=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("useSSUMapOnly")){
-				useSSUMapOnly=Tools.parseBoolean(b);
+				useSSUMapOnly=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("useSSUMapOnlyEuks") || a.equalsIgnoreCase("SSUMapOnlyEuks")){
-				useSSUMapOnlyEuks=Tools.parseBoolean(b);
+				useSSUMapOnlyEuks=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("useSSUMapOnlyProks") || a.equalsIgnoreCase("SSUMapOnlyProks")){
-				useSSUMapOnlyProks=Tools.parseBoolean(b);
+				useSSUMapOnlyProks=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("preferSSUMapForProks") || a.equalsIgnoreCase("preferSSUMapProks")){
-				preferSSUMapProks=Tools.parseBoolean(b);
+				preferSSUMapProks=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equalsIgnoreCase("clearAll")){
-				clear16S=clear18S=Tools.parseBoolean(b);
+				clear16S=clear18S=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("clear16S")){
-				clear16S=Tools.parseBoolean(b);
+				clear16S=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("clear18S")){
-				clear18S=Tools.parseBoolean(b);
+				clear18S=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("clear16SEuks")){
-				clear16SEuks=Tools.parseBoolean(b);
+				clear16SEuks=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("clear18SEuks")){
-				clear18SEuks=Tools.parseBoolean(b);
+				clear18SEuks=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("clear16SProks")){
-				clear16SProks=Tools.parseBoolean(b);
+				clear16SProks=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("clear18SProks")){
-				clear18SProks=Tools.parseBoolean(b);
+				clear18SProks=Parse.parseBoolean(b);
 			}
 			
 			else if(parser.parse(arg, a, b)){
