@@ -728,7 +728,7 @@ public class BlacklistMaker extends SketchObject {
 				long x=AminoAcid.baseToNumber[b];
 				long x2=AminoAcid.baseToComplementNumber[b];
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				if(eTracker!=null){eTracker.add(b);}
 
 				if(x<0){
