@@ -253,7 +253,7 @@ public class InvertKey extends SketchObject {
 			long x=AminoAcid.baseToNumber[b];
 			long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			if(x<0){len=0; rkmer=0;}else{len++;}
 			if(len>=k){
 				kmersProcessed++;
