@@ -887,7 +887,7 @@ public class Sketch extends SketchObject implements Comparable<Sketch>, Cloneabl
 			long x=AminoAcid.baseToNumber[b];
 			long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 			if(x<0){len=0; rkmer=0;}else{len++;}
 			if(len>=k){
 //				long z=Tools.max(kmer, rkmer);
