@@ -13,6 +13,7 @@ import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -121,13 +122,13 @@ public class SketchMaker extends SketchObject {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("files")){
 				files_=Integer.parseInt(b);
 			}else if(a.equals("minsize")){
-				minSizeKmers_=Tools.parseIntKMG(b);
+				minSizeKmers_=Parse.parseIntKMG(b);
 			}else if(a.equals("prefilter")){
-				prefilter=Tools.parseBoolean(b);
+				prefilter=Parse.parseBoolean(b);
 				setPrefilter=true;
 			}
 			
@@ -148,13 +149,13 @@ public class SketchMaker extends SketchObject {
 				int underscore=a.indexOf('_', 0);
 				outMeta.add(a.substring(underscore+1)+":"+b);
 			}else if(a.equals("parsesubunit")){
-				parseSubunit=Tools.parseBoolean(b);
+				parseSubunit=Parse.parseBoolean(b);
 			}
 			
 			else if(parseMode(arg, a, b)>-1){
 				mode_=parseMode(arg, a, b);
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}
 			
@@ -169,11 +170,11 @@ public class SketchMaker extends SketchObject {
 			}
 			
 			else if(a.equals("tossjunk")){
-				tossJunk=Tools.parseBoolean(b);
+				tossJunk=Parse.parseBoolean(b);
 			}
 			
 //			else if(a.equals("silva")){//Handled by parser
-//				TaxTree.SILVA_MODE=Tools.parseBoolean(b);
+//				TaxTree.SILVA_MODE=Parse.parseBoolean(b);
 //			}
 			
 			else if(a.equals("taxlevel") || a.equals("tl") || a.equals("level") || a.equals("lv")){
@@ -1352,7 +1353,7 @@ public class SketchMaker extends SketchObject {
 	long outSpid=-1;
 	long outImgID=-1;
 	ArrayList<String> outMeta=null;
-	boolean parseSubunit=false;
+	static boolean parseSubunit=false;
 	
 	/*--------------------------------------------------------------*/
 
