@@ -608,7 +608,7 @@ public class SketchObject {
 	/** Taken from Thomas Wang, Jan 1997:
 	 * http://web.archive.org/web/20071223173210/http://www.concentric.net/~Ttwang/tech/inthash.htm
 	 * 
-	 *  This is much faster than the table version.  Results seem similar though.
+	 *  This is much faster than the table version.  Results seem similar y.
 	 */
 	private static long hash64shift(long key){
 		key = (~key) + (key << 21); // key = (key << 21) - key - 1;
@@ -1056,16 +1056,27 @@ public class SketchObject {
 		return list;
 	}
 	
-	private static final String IMG_PATH="/global/projectb/sandbox/gaag/bbtools/img/current/img#.sketch";
-	private static final String NT_PATH="/global/projectb/sandbox/gaag/bbtools/nt/current/taxa#.sketch";
-	private static final String NR_PATH="/global/projectb/sandbox/gaag/bbtools/nr/current/taxa#.sketch";
-	private static final String REFSEQ_PATH="/global/projectb/sandbox/gaag/bbtools/refseq/current/taxa#.sketch";
-	private static final String REFSEQ_PATH_BIG="/global/projectb/sandbox/gaag/bbtools/refseq/current/big#.sketch";
-	private static final String SILVA_PATH="/global/projectb/sandbox/gaag/bbtools/silva/latest/both_taxa#.sketch";
-	private static final String PROKPROT_PATH="/global/projectb/sandbox/gaag/bbtools/refseq/current/prot/taxa#.sketch";
-	private static final String PROKPROT_PATH_BIG="/global/projectb/sandbox/gaag/bbtools/refseq/current/prot/big#.sketch";
-	private static final String MITO_PATH="/global/projectb/sandbox/gaag/bbtools/mito2/taxa#.sketch";
-	private static final String FUNGI_PATH="/global/projectb/sandbox/gaag/bbtools/mito2/fungi#.sketch";
+	private static final String IMG_PATH="/global/cfs/cdirs/bbtools/img/current/img#.sketch";
+	private static final String NT_PATH="/global/cfs/cdirs/bbtools/nt/current/taxa#.sketch";
+	private static final String NR_PATH="/global/cfs/cdirs/bbtools/nr/current/taxa#.sketch";
+	private static final String REFSEQ_PATH="/global/cfs/cdirs/bbtools/refseq/current/taxa#.sketch";
+	private static final String REFSEQ_PATH_BIG="/global/cfs/cdirs/bbtools/refseq/current/big#.sketch";
+	private static final String SILVA_PATH="/global/cfs/cdirs/bbtools/silva/latest/both_taxa#.sketch";
+	private static final String PROKPROT_PATH="/global/cfs/cdirs/bbtools/refseq/current/prot/taxa#.sketch";
+	private static final String PROKPROT_PATH_BIG="/global/cfs/cdirs/bbtools/refseq/current/prot/big#.sketch";
+	private static final String MITO_PATH="/global/cfs/cdirs/bbtools/mito2/taxa#.sketch";
+	private static final String FUNGI_PATH="/global/cfs/cdirs/bbtools/mito2/fungi#.sketch";
+
+	private static final String IMG_PATH_IGBVM="/data/sketch/img/current/img#.sketch";
+	private static final String NT_PATH_IGBVM="/data/sketch/nt/current/taxa#.sketch";
+	private static final String NR_PATH_IGBVM="/data/sketch/nr/current/taxa#.sketch";
+	private static final String REFSEQ_PATH_IGBVM="/data/sketch/refseq/current/taxa#.sketch";
+	private static final String REFSEQ_PATH_BIG_IGBVM="/data/sketch/refseq/current/big#.sketch";
+	private static final String SILVA_PATH_IGBVM="/data/sketch/silva/current/both_taxa#.sketch";
+	private static final String PROKPROT_PATH_IGBVM="/data/sketch/refseq/current/prot/taxa#.sketch";
+	private static final String PROKPROT_PATH_BIG_IGBVM="/data/sketch/refseq/current/prot/big#.sketch";
+	private static final String MITO_PATH_IGBVM="/data/sketch/mito2/taxa#.sketch";
+	private static final String FUNGI_PATH_IGBVM="/data/sketch/mito2/fungi#.sketch";
 
 	private static final String IMG_PATH_AWS=null;
 	private static final String NT_PATH_AWS="/test1/sketch/latest/nt/taxa#.sketch";
@@ -1076,16 +1087,16 @@ public class SketchObject {
 	private static final String MITO_PATH_AWS=null;
 	private static final String FUNGI_PATH_AWS=null;
 
-	public static final String IMG_PATH(){return Shared.AWS ? IMG_PATH_AWS : IMG_PATH;}
-	public static final String NT_PATH(){return Shared.AWS ? NT_PATH_AWS : NT_PATH;}
-	public static final String NR_PATH(){return Shared.AWS ? NR_PATH_AWS : NR_PATH;}
-	public static final String REFSEQ_PATH(){return Shared.AWS ? REFSEQ_PATH_AWS : REFSEQ_PATH;}
-	public static final String REFSEQ_PATH_BIG(){return REFSEQ_PATH_BIG;}
-	public static final String SILVA_PATH(){return Shared.AWS ? SILVA_PATH_AWS : SILVA_PATH;}
-	public static final String PROKPROT_PATH(){return Shared.AWS ? PROKPROT_PATH_AWS : PROKPROT_PATH;}
-	public static final String PROKPROT_PATH_BIG(){return PROKPROT_PATH_BIG;}
-	public static final String MITO_PATH(){return Shared.AWS ? MITO_PATH_AWS : MITO_PATH;}
-	public static final String FUNGI_PATH(){return Shared.AWS ? FUNGI_PATH_AWS : FUNGI_PATH;}
+	public static final String IMG_PATH(){return Shared.IGBVM ? IMG_PATH_IGBVM : Shared.AWS ? IMG_PATH_AWS : IMG_PATH;}
+	public static final String NT_PATH(){return Shared.IGBVM ? NT_PATH_IGBVM : Shared.AWS ? NT_PATH_AWS : NT_PATH;}
+	public static final String NR_PATH(){return Shared.IGBVM ? NR_PATH_IGBVM : Shared.AWS ? NR_PATH_AWS : NR_PATH;}
+	public static final String REFSEQ_PATH(){return Shared.IGBVM ? REFSEQ_PATH_IGBVM : Shared.AWS ? REFSEQ_PATH_AWS : REFSEQ_PATH;}
+	public static final String REFSEQ_PATH_BIG(){return Shared.IGBVM ? REFSEQ_PATH_BIG_IGBVM : REFSEQ_PATH_BIG;}
+	public static final String SILVA_PATH(){return Shared.IGBVM ? SILVA_PATH_IGBVM : Shared.AWS ? SILVA_PATH_AWS : SILVA_PATH;}
+	public static final String PROKPROT_PATH(){return Shared.IGBVM ? PROKPROT_PATH_IGBVM : Shared.AWS ? PROKPROT_PATH_AWS : PROKPROT_PATH;}
+	public static final String PROKPROT_PATH_BIG(){return Shared.IGBVM ? PROKPROT_PATH_BIG_IGBVM : PROKPROT_PATH_BIG;}
+	public static final String MITO_PATH(){return Shared.IGBVM ? MITO_PATH_IGBVM : Shared.AWS ? MITO_PATH_AWS : MITO_PATH;}
+	public static final String FUNGI_PATH(){return Shared.IGBVM ? FUNGI_PATH_IGBVM : Shared.AWS ? FUNGI_PATH_AWS : FUNGI_PATH;}
 	
 	/*--------------------------------------------------------------*/
 	/*----------------           Getters            ----------------*/
