@@ -18,6 +18,7 @@ import kmer.HashForest;
 import kmer.KmerNode;
 import kmer.KmerTableSet;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Shared;
 import shared.Tools;
 import stream.ConcurrentReadInputStream;
@@ -500,7 +501,7 @@ public final class SketchTool extends SketchObject {
 								}else if(s.startsWith("H:")){//Hash version
 									hashVersion_sketch=Integer.parseInt(sub);
 								}else if(s.startsWith("BC:") || s.startsWith("BASECOUNTS:")){//ACGTN
-									baseCounts=Tools.parseLongArray(sub);
+									baseCounts=Parse.parseLongArray(sub);
 								}else if(s.startsWith("GS:") || s.startsWith("GSIZE:")){//Genomic bases
 									genomeSizeBases=Long.parseLong(sub);
 								}else if(s.startsWith("GK:") || s.startsWith("GKMERS:")){//Genomic kmers
@@ -558,7 +559,7 @@ public final class SketchTool extends SketchObject {
 					}
 				}else{
 					long x=(counts ? Sketch.parseA48C(line, countList) : A48 ? Sketch.parseA48(line) :
-						HEX ? Sketch.parseHex(line) : NUC ? Sketch.parseNuc(line) : Tools.parseLong(line));
+						HEX ? Sketch.parseHex(line) : NUC ? Sketch.parseNuc(line) : Parse.parseLong(line));
 //					System.err.println("sum="+sum+", x="+x+" -> "+(sum+x));
 					sum+=x;
 					assert(x>=0 || NUC) : "x="+x+"\nline="+new String(line)+"\nheader="+(lastHeader==null ? "null" : new String(lastHeader))+"\nlineNum="+bf.lineNum()+"\n";
@@ -736,7 +737,7 @@ public final class SketchTool extends SketchObject {
 							}else if(s.startsWith("H:")){//Hash version
 								hashVersion_sketch=Integer.parseInt(sub);
 							}else if(s.startsWith("BC:") || s.startsWith("BASECOUNTS:")){//ACGTN
-								baseCounts=Tools.parseLongArray(sub);
+								baseCounts=Parse.parseLongArray(sub);
 							}else if(s.startsWith("GS:") || s.startsWith("GSIZE:")){//Genomic bases
 								genomeSizeBases=Long.parseLong(sub);
 							}else if(s.startsWith("GK:") || s.startsWith("GKMERS:")){//Genomic kmers
@@ -806,7 +807,7 @@ public final class SketchTool extends SketchObject {
 				start++;
 				
 				long x=(counts ? Sketch.parseA48C(bb, countList) : A48 ? Sketch.parseA48(bb) :
-					HEX ? Sketch.parseHex(bb) : NUC ? Sketch.parseNuc(bb) : Tools.parseLong(bb.array, 0, bb.length));
+					HEX ? Sketch.parseHex(bb) : NUC ? Sketch.parseNuc(bb) : Parse.parseLong(bb.array, 0, bb.length));
 				//					System.err.println("sum="+sum+", x="+x+" -> "+(sum+x));
 				sum+=x;
 				assert(x>=0 || NUC) : "x="+x+"\nline="+bb+"\nheader="+(lastHeader==null ? "null" : new String(lastHeader))+"\n";
@@ -975,7 +976,7 @@ public final class SketchTool extends SketchObject {
 								}else if(s.startsWith("H:")){//Hash version
 									hashVersion_sketch=Integer.parseInt(sub);
 								}else if(s.startsWith("BC:") || s.startsWith("BASECOUNTS:")){//ACGTN
-									baseCounts=Tools.parseLongArray(sub);
+									baseCounts=Parse.parseLongArray(sub);
 								}else if(s.startsWith("GS:") || s.startsWith("GSIZE:")){//Genomic bases
 									genomeSizeBases=Long.parseLong(sub);
 								}else if(s.startsWith("GK:") || s.startsWith("GKMERS:")){//Genomic kmers
