@@ -108,6 +108,10 @@ public class Shuffle2 {
 				ascending=!Parse.parseBoolean(b);
 			}else if(a.equals("maxfiles") || a.equals("files")){
 				maxFiles=Integer.parseInt(b);
+			}else if(a.equals("seed")){
+				seed=Long.parseLong(b);
+			}else if(a.equals("deterministic")){
+				seed=Parse.parseBoolean(b) ? 1 : -1;
 			}else if(a.equals("parse_flag_goes_here")){
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
@@ -119,6 +123,7 @@ public class Shuffle2 {
 			}
 		}
 		
+		randy=Shared.threadLocalRandom(seed);
 		SamLine.SET_FROM_OK=true;
 		
 		{//Process parser fields
@@ -705,6 +710,8 @@ public class Shuffle2 {
 	/** Max files to merge per pass */
 	private int maxFiles=16;
 	
+	private long seed=-1;
+	
 	static Random randy=Shared.threadLocalRandom();
 	
 	/*--------------------------------------------------------------*/
