@@ -11,6 +11,7 @@ import dna.Data;
 import dna.Gene;
 import dna.ScafLoc;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Shared;
 import shared.Tools;
 import structures.ByteBuilder;
@@ -489,7 +490,7 @@ public class SamLine implements Serializable {
 		
 		while(b<s.length && s[b]!='\t'){b++;}
 		assert(b>a) : "Missing field 1: "+new String(s);
-		flag=Tools.parseInt(s, a, b);
+		flag=Parse.parseInt(s, a, b);
 		b++;
 		a=b;
 		
@@ -507,13 +508,13 @@ public class SamLine implements Serializable {
 		
 		while(b<s.length && s[b]!='\t'){b++;}
 		assert(b>a) : "Missing field 3: "+new String(s);
-		pos=Tools.parseInt(s, a, b);
+		pos=Parse.parseInt(s, a, b);
 		b++;
 		a=b;
 		
 		while(b<s.length && s[b]!='\t'){b++;}
 		assert(b>a) : "Missing field 4: "+new String(s);
-		mapq=Tools.parseInt(s, a, b);
+		mapq=Parse.parseInt(s, a, b);
 		b++;
 		a=b;
 		
@@ -531,13 +532,13 @@ public class SamLine implements Serializable {
 		
 		while(b<s.length && s[b]!='\t'){b++;}
 		assert(b>a) : "Missing field 7: "+new String(s);
-		if(PARSE_7){pnext=(b==a+1 && s[a]=='*' ? 0 :Tools.parseInt(s, a, b));}
+		if(PARSE_7){pnext=(b==a+1 && s[a]=='*' ? 0 :Parse.parseInt(s, a, b));}
 		b++;
 		a=b;
 		
 		while(b<s.length && s[b]!='\t'){b++;}
 		assert(b>a) : "Missing field 8: "+new String(s);
-		if(PARSE_8){tlen=Tools.parseInt(s, a, b);}
+		if(PARSE_8){tlen=Parse.parseInt(s, a, b);}
 		b++;
 		a=b;
 		
@@ -637,7 +638,7 @@ public class SamLine implements Serializable {
 		
 		while(b<s.length && s[b]!='\t'){b++;}
 		assert(b>a) : "Missing field 1: "+new String(s);
-		int flag=Tools.parseInt(s, a, b);
+		int flag=Parse.parseInt(s, a, b);
 		return flag;
 	}
 	
@@ -1173,7 +1174,7 @@ public class SamLine implements Serializable {
 	 */
 	public static final int[] cigarToMdsiMax(String cigar) {
 		if(cigar==null){return null;}
-		int[] msdic=new int[5];
+		int[] msdic=KillSwitch.allocInt1D(5);
 		
 		int current=0;
 		for(int i=0; i<cigar.length(); i++){
@@ -1235,7 +1236,7 @@ public class SamLine implements Serializable {
 	 */
 	public static final int[] cigarToMsdic(String cigar) {
 		if(cigar==null){return null;}
-		int[] msdic=new int[5];
+		int[] msdic=KillSwitch.allocInt1D(5);
 		
 		int current=0;
 		for(int i=0; i<cigar.length(); i++){
