@@ -300,32 +300,37 @@ public final class IntList{
 		return size-1;
 	}
 	
+
+	
 	public final void shrinkToUnique(){
-		//Assumes sorted.
-		if(size<=0){
-			shrink();
-			return;
-		}
+		condense();
+		shrink();
+	}
+	
+	//In-place.
+	//Assumes sorted.
+	public final void condense(){
+		if(size<=1){return;}
 		
-		int unique=1;
+		int i=0, j=1;
+		for(; j<size && array[i]<array[j]; i++, j++){}//skip while strictly ascending 
 		
-		for(int i=1; i<size; i++){
-			assert(array[i]>=array[i-1]);
-			if(array[i]!=array[i-1]){unique++;}
-		}
-		if(unique==array.length){return;}
-		int[] alt=KillSwitch.allocInt1D(unique);
-		
-		alt[0]=array[0];
-		for(int i=1, j=1; j<unique; i++){
-			if(array[i]!=array[i-1]){
-				alt[j]=array[i];
-				j++;
+		int dupes=0;
+		for(; j<size; j++){//This only enters at the first nonascending pair
+			int a=array[i], b=array[j];
+			assert(a<=b) : "Unsorted: "+i+", "+j+", "+a+", "+b;
+			if(b>a){
+				i++;
+				array[i]=b;
+			}else{
+				//do nothing
+				dupes++;
+				assert(a==b);
 			}
 		}
-		
-		array=alt;
-		size=alt.length;
+		assert(dupes==(size-(i+1)));
+		assert(size>=(i+1));
+		size=i+1;
 	}
 	
 	/*--------------------------------------------------------------*/
