@@ -10,6 +10,26 @@ import shared.Tools;
 
 public final class LongList{
 	
+	public static void main(String[] args){
+		LongList list=new LongList();
+		list.add(3);
+		list.add(1);
+		list.add(2);
+		list.add(5);
+		list.add(2);
+		list.add(1);
+		list.add(7);
+		list.add(3);
+		list.add(3);
+		System.err.println(list);
+		list.sort();
+		System.err.println(list);
+		list.condense();
+		System.err.println(list);
+		list.condense();
+		System.err.println(list);
+	}
+	
 	public LongList(){this(256);}
 	
 	public LongList(int initial){
@@ -266,33 +286,64 @@ public final class LongList{
 		return size-1;
 	}
 	
-	//TODO: This could be done in-place.
+//	//TODO: This could be done in-place.
+//	public final void shrinkToUnique(){
+//		//Assumes sorted.
+//		if(size<=0){
+//			shrink();
+//			return;
+//		}
+//		
+//		int unique=1;
+//		
+//		for(int i=1; i<size; i++){
+//			assert(array[i]>=array[i-1]);
+//			if(array[i]!=array[i-1]){unique++;}
+//		}
+//		if(unique==array.length){return;}
+//		long[] alt=KillSwitch.allocLong1D(unique);
+//		
+//		alt[0]=array[0];
+//		for(int i=1, j=1; j<unique; i++){
+//			if(array[i]!=array[i-1]){
+//				alt[j]=array[i];
+//				j++;
+//			}
+//		}
+//		
+//		array=alt;
+//		size=alt.length;
+//	}
+	
 	public final void shrinkToUnique(){
-		//Assumes sorted.
-		if(size<=0){
-			shrink();
-			return;
-		}
+		condense();
+		shrink();
+	}
+	
+	//In-place.
+	//Assumes sorted.
+	public final void condense(){
+		if(size<=1){return;}
 		
-		int unique=1;
+		int i=0, j=1;
+		for(; j<size && array[i]<array[j]; i++, j++){}//skip while strictly ascending 
 		
-		for(int i=1; i<size; i++){
-			assert(array[i]>=array[i-1]);
-			if(array[i]!=array[i-1]){unique++;}
-		}
-		if(unique==array.length){return;}
-		long[] alt=KillSwitch.allocLong1D(unique);
-		
-		alt[0]=array[0];
-		for(int i=1, j=1; j<unique; i++){
-			if(array[i]!=array[i-1]){
-				alt[j]=array[i];
-				j++;
+		int dupes=0;
+		for(; j<size; j++){//This only enters at the first nonascending pair
+			long a=array[i], b=array[j];
+			assert(a<=b) : "Unsorted: "+i+", "+j+", "+a+", "+b;
+			if(b>a){
+				i++;
+				array[i]=b;
+			}else{
+				//do nothing
+				dupes++;
+				assert(a==b);
 			}
 		}
-		
-		array=alt;
-		size=alt.length;
+		assert(dupes==(size-(i+1)));
+		assert(size>=(i+1));
+		size=i+1;
 	}
 	
 	@Override
