@@ -14,6 +14,10 @@ public class StringNum implements Comparable<StringNum> {
 	public long increment(long x){
 		return (n=n+x);
 	}
+	
+	public void add(StringNum sn) {
+		n+=sn.n;
+	}
 
 	/* (non-Javadoc)
 	 * @see java.lang.Comparable#compareTo(java.lang.Object)
