@@ -354,11 +354,14 @@ public class AccessionToTaxid {
 //		if(STRIP_UNDERSCORE){
 //			accession=accession.replaceAll("[_-]", "");
 //		}
-		
-		int dot=accession.indexOf('.');
-		int len=(dot<0 ? accession.length() : dot);
-		
-		
+
+		int len=accession.length();
+		for(int i=0; i<len; i++){
+			char c=accession.charAt(i);
+			if(c=='.' || c==':' || c==','){
+				len=i; break;
+			}
+		}
 		
 		if(USE_TABLES){
 			if(AnalyzeAccession.codeMap!=null){
@@ -376,7 +379,7 @@ public class AccessionToTaxid {
 			}
 		}
 		
-		if(dot>-1){accession=accession.substring(0,  dot);}
+		if(len<accession.length()){accession=accession.substring(0, len);}
 		if(accession.length()<1){return -1;}
 		int way=accession.charAt(0);
 		Integer value=maps[way].get(accession);
@@ -387,7 +390,8 @@ public class AccessionToTaxid {
 		if(s==null || s.length()<4){return false;}
 		for(int i=0; i<s.length(); i++){
 			char c=s.charAt(i);
-			if((c>='0' && c<='9') || (c>='A' && c<='Z') /*|| (c>='a' && c<='z')*/ || c=='.' || c=='_' || c=='-'){
+			if((c>='0' && c<='9') || (c>='A' && c<='Z') /*|| (c>='a' && c<='z')*/ 
+					|| c=='.' || c=='_' || c=='-' || c==':' || c==','){
 				//do nothing
 			}else{
 				return false;
@@ -400,7 +404,7 @@ public class AccessionToTaxid {
 		long number=0;
 		for(int i=0, max=accession.length(); i<max; i++){
 			long c=accession.charAt(i);
-			if(c=='.'){break;}
+			if(c=='.' || c==':' || c==','){break;}
 			if(c>='0' && c<='9'){c=c-'0';}
 			else if(c>='A' && c<='Z'){c=c+offset;}
 			else if(c=='_' || c=='-'){c=10;}//Collision, but should be OK
@@ -417,7 +421,7 @@ public class AccessionToTaxid {
 		long number=0;
 		for(int i=0; i<limit; i++){
 			long c=line[i];
-			if(c=='.'){break;}
+			if(c=='.' || c==':' || c==','){break;}
 			if(c>='0' && c<='9'){c=c-'0';}
 			else if(c>='A' && c<='Z'){c=c+offset;}
 			else if(c=='_' || c=='-'){c=10;}//Collision, but should be OK
@@ -456,6 +460,25 @@ public class AccessionToTaxid {
 		return ncbi;
 	}
 	
+	public static int parseLineToTaxid_2col(final byte[] line, final byte delimiter){
+		int a=0, b=0;
+		
+		final int ncbi;
+		
+		while(b<line.length && line[b]!=delimiter){b++;}
+		assert(b>a) : "Missing field 0: "+new String(line);
+		b++;
+		a=b;
+		
+		while(b<line.length && line[b]!=delimiter){b++;}
+		assert(b>a) : "Missing field 1: "+new String(line);
+		ncbi=Parse.parseInt(line, a, b);
+		b++;
+		a=b;
+		
+		return ncbi;
+	}
+	
 	/*--------------------------------------------------------------*/
 	
 	public static class HashThread extends Thread {
@@ -500,7 +523,8 @@ public class AccessionToTaxid {
 						linesProcessedT++;
 						bytesProcessedT+=line.length;
 
-						final boolean valid=(!Tools.startsWith(line, "accession\t")) & !skipParse;
+//						final boolean valid=(!Tools.startsWith(line, "accession\t")) & !skipParse;
+						final boolean valid=(!Tools.startsWith(line, "accession")) & !skipParse;
 						//					assert(valid); //Not true if concatenated
 
 						//					if(Tools.startsWith(line, "NZ_LM994619")){
@@ -584,6 +608,8 @@ public class AccessionToTaxid {
 //			return true;
 //		}
 		
+		//This code is no longer used and can be safely deleted.
+		@Deprecated
 		public boolean parseLine(final byte[] line, final byte delimiter){
 			int a=0, b=0;
 			
@@ -593,7 +619,7 @@ public class AccessionToTaxid {
 			while(b<line.length && line[b]!=delimiter){b++;}
 			assert(b>a) : "Missing field 0: "+new String(line);
 			accession=new String(line, a, b-a);
-			final int dot=accession.indexOf('.');
+			final int dot=accession.indexOf('.');//and :, but this is deprecated.
 			if(dot>=0){//Should never happen
 //				System.err.println(accession);
 //				assert(dot==accession.length()-2) : accession;
@@ -665,7 +691,8 @@ public class AccessionToTaxid {
 			
 			final int ncbi, gi;
 
-			while(b<line.length && line[b]!=delimiter && line[b]!='.'){b++;}//parse unique part of accession
+			while(b<line.length && line[b]!=delimiter 
+					&& line[b]!='.' && line[b]!=':' && line[b]!=','){b++;}//parse unique part of accession
 			final int dot=b;
 			assert(b>a) : "Missing field 0: "+new String(line);
 			while(b<line.length && line[b]!=delimiter){b++;}//skip the rest of the accession
@@ -738,6 +765,12 @@ public class AccessionToTaxid {
 //				System.err.println("K");
 			}
 			
+			if(distributed){
+				String accession=new String(line, 0, dot);//slow
+				assert(accession.equals(accession.toUpperCase()));//TODO: Disable. (slow)
+				if(accession.hashCode()%serverCount!=serverNum){return false;}
+			}
+			
 			if(USE_TABLES){
 				if(AnalyzeAccession.codeMap!=null){
 //					if(dot>AnalyzeAccession.longestPattern){return false;}
@@ -827,6 +860,10 @@ public class AccessionToTaxid {
 	private static final long offset=-'A'+11;
 	private static final long offsetLower=-'a'+11;
 	
+	public static int serverNum=0;
+	public static int serverCount=1;
+	public static boolean distributed=false;
+	
 	/*--------------------------------------------------------------*/
 	
 	private PrintStream outstream=System.err;
