@@ -8,6 +8,7 @@ import java.util.HashMap;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -87,7 +88,7 @@ public class SplitByTaxa {
 			if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("taxlevel") || a.equals("tl") || a.equals("level") || a.equals("lv")){
 				taxLevelE=TaxTree.parseLevelExtended(b);
 			}else if(a.equals("table") || a.equals("gi") || a.equals("gitable")){
