@@ -2479,13 +2479,16 @@ public class TaxTree implements Serializable{
 	
 	/* For these fields, see the corresponding functions, below.
 	 * They define the default paths to various data on NERSC. */
-	
-	private static final String defaultTaxPathNersc="/global/projectb/sandbox/gaag/bbtools/tax/latest";
+
+	private static final String defaultTaxPathNersc="/global/cfs/cdirs/bbtools/tax/latest";
 	private static final String defaultTaxPathAws="/test1/tax/latest";
-	private static final String default16SFileNersc="/global/projectb/sandbox/gaag/bbtools/silva/16S_consensus_with_silva_maxns10_taxsorted.fa.gz";
+	private static final String defaultTaxPathIGBVM="/data/tax/latest";
+	private static final String default16SFileNersc="/global/cfs/cdirs/bbtools/silva/16S_consensus_with_silva_maxns10_taxsorted.fa.gz";
 	private static final String default16SFileAws="/test1/16S_consensus_with_silva_maxns10_taxsorted.fa.gz";
-	private static final String default18SFileNersc="/global/projectb/sandbox/gaag/bbtools/silva/18S_consensus_silva_maxns10_taxsorted.fa.gz";
+	private static final String default16SFileIGBVM="/data/sketch/silva/16S_consensus_with_silva_maxns10_taxsorted.fa.gz";
+	private static final String default18SFileNersc="/global/cfs/cdirs/bbtools/silva/18S_consensus_silva_maxns10_taxsorted.fa.gz";
 	private static final String default18SFileAws="/test1/18S_consensus_silva_maxns10_taxsorted.fa.gz";
+	private static final String default18SFileIGBVM="/data/sketch/silva/18S_consensus_with_silva_maxns10_taxsorted.fa.gz";
 	
 	private static final String defaultImgFile="TAX_PATH/imgDump.txt";
 	private static final String defaultTableFile="TAX_PATH/gitable.int1d.gz";
@@ -2493,7 +2496,9 @@ public class TaxTree implements Serializable{
 	private static final String defaultPatternFile="TAX_PATH/patterns.txt";
 	private static final String defaultSizeFile="TAX_PATH/taxsize.tsv.gz";
 
-	private static final String defaultAccessionFile="TAX_PATH/shrunk.prot.accession2taxid.gz,"
+	private static final String defaultAccessionFile=
+			//"TAX_PATH/shrunk.protF.accession2taxid.gz," +
+			"TAX_PATH/shrunk.prot.accession2taxid.gz,"
 			+ "TAX_PATH/shrunk.nucl_wgs.accession2taxid.gz,"
 			+ "TAX_PATH/shrunk.nucl_gb.accession2taxid.gz,"
 			+ "TAX_PATH/shrunk.dead_prot.accession2taxid.gz,"
@@ -2505,17 +2510,17 @@ public class TaxTree implements Serializable{
 
 	/** For setting TAX_PATH, the root to taxonomy files */
 	public static final String defaultTaxPath(){
-		return (Shared.AWS && !Shared.NERSC) ? defaultTaxPathAws : defaultTaxPathNersc;
+		return (Shared.AWS && !Shared.NERSC) ? defaultTaxPathAws : Shared.IGBVM ? defaultTaxPathIGBVM : defaultTaxPathNersc;
 	}
 
 	/** 16S consensus sequences per TaxID */
 	public static final String default16SFile(){
-		return (Shared.AWS && !Shared.NERSC) ? default16SFileAws : default16SFileNersc;
+		return (Shared.AWS && !Shared.NERSC) ? default16SFileAws : Shared.IGBVM ? default16SFileIGBVM : default16SFileNersc;
 	}
 
 	/** 18S consensus sequences per TaxID */
 	public static final String default18SFile(){
-		return (Shared.AWS && !Shared.NERSC) ? default18SFileAws : default18SFileNersc;
+		return (Shared.AWS && !Shared.NERSC) ? default18SFileAws : Shared.IGBVM ? default18SFileIGBVM : default18SFileNersc;
 	}
 
 	/** Path to all taxonomy files, substituted in to make specific file paths */
@@ -2525,8 +2530,15 @@ public class TaxTree implements Serializable{
 	public static final String defaultTableFile(){return defaultTableFile.replaceAll("TAX_PATH", TAX_PATH);}
 	/** Location of tree.taxtree.gz */
 	public static final String defaultTreeFile(){return defaultTreeFile.replaceAll("TAX_PATH", TAX_PATH);}
+	
+	//Use the prot.FULL.gz ncbi file.
+	public static boolean protFull=false;
+	
 	/** Location of shrunk.*.accession2taxid.gz (all accession files, comma-delimited) */
-	public static final String defaultAccessionFile(){return defaultAccessionFile.replaceAll("TAX_PATH", TAX_PATH);}
+	public static final String defaultAccessionFile(){
+		String s=(protFull ? "TAX_PATH/shrunk.protF.accession2taxid.gz," : "")+defaultAccessionFile;
+		return s.replaceAll("TAX_PATH", TAX_PATH);
+	}
 	/** Location of patterns.txt, which holds information about observed accession string formats */
 	public static final String defaultPatternFile(){return defaultPatternFile.replaceAll("TAX_PATH", TAX_PATH);}
 	/** Location of imgDump.txt, which translates IMG to NCBI IDs for internal JGI use */
