@@ -7,6 +7,7 @@ import java.util.ArrayList;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -132,11 +133,11 @@ public class A_SampleMT implements Accumulator<A_SampleMT.ProcessThread> {
 			if(b!=null && b.equalsIgnoreCase("null")){b=null;}
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
