@@ -193,7 +193,7 @@ public class Kmer implements Cloneable {
 			
 			//Update kmers
 			array1[i]=((array1[i]<<2)|x)&mask;
-			array2[j]=(array2[j]>>>2)|(x2<<shift2);
+			array2[j]=((array2[j]>>>2)|(x2<<shift2))&mask;
 			
 			x=y;
 			x2=y2;
