@@ -15,6 +15,7 @@ import fileIO.ReadWrite;
 import fileIO.TextFile;
 import pacbio.CalcCoverageFromSites;
 import pacbio.SiteR;
+import shared.Parse;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -48,12 +49,12 @@ public class GenerateVarlets {
 			String[] split=arg.split("=");
 			if(arg.equals("condense")){CONDENSE=true;}
 			else if(arg.startsWith("condense=")){
-				CONDENSE=Tools.parseBoolean(split[1]);
+				CONDENSE=Parse.parseBoolean(split[1]);
 			}else if(arg.equals("condensesnps")){CONDENSE_SNPS=true;}
 			else if(arg.startsWith("condensesnps=")){
-				CONDENSE_SNPS=Tools.parseBoolean(split[1]);
+				CONDENSE_SNPS=Parse.parseBoolean(split[1]);
 			}else if(arg.startsWith("splitsubs=")){
-				SPLIT_SUBS=Tools.parseBoolean(split[1]);
+				SPLIT_SUBS=Parse.parseBoolean(split[1]);
 			}else if(arg.equals("tosssolo1")){
 				TOSS_SOLO1=true;
 			}else if(arg.equals("tosssolo2")){
