@@ -6,6 +6,7 @@ import java.util.HashMap;
 
 import dna.Data;
 import fileIO.TextStreamWriter;
+import shared.Parse;
 import shared.PreParser;
 import shared.Shared;
 import shared.Timer;
@@ -65,7 +66,7 @@ public class StackVariations2 {
 			}else if(a.equals("blocksize")){
 				GenerateVarlets2.BLOCKSIZE=(Integer.parseInt(b));
 			}else if(a.equals("deletefiles") || a.startsWith("deletetemp") || a.startsWith("deleteinput") || a.equals("delete")){
-				DELETE_INPUT=(Tools.parseBoolean(b));
+				DELETE_INPUT=(Parse.parseBoolean(b));
 			}else{
 				throw new RuntimeException("Unknown parameter "+args[i]);
 			}
