@@ -12,6 +12,7 @@ import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextFile;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -111,42 +112,44 @@ public class CallVariants2 {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("multi") || a.equals("multisample")){
-				boolean multi=Tools.parseBoolean(b);
+				boolean multi=Parse.parseBoolean(b);
 				assert(multi) : "\nThis program is for multisample variant calling.  Please use CallVariants for single-sample variant calling.\n";
 			}else if(a.equals("ploidy")){
 				ploidy=Integer.parseInt(b);
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(a.equals("ss") || a.equals("samstreamer")){
 				if(b!=null && Tools.isDigit(b.charAt(0))){
 					useStreamer=true;
 					streamerThreads=Tools.max(1, Integer.parseInt(b));
 				}else{
-					useStreamer=Tools.parseBoolean(b);
+					useStreamer=Parse.parseBoolean(b);
 				}
 			}else if(a.equals("parsename")){
-				SamLine.PARSE_0=Tools.parseBoolean(b);
+				SamLine.PARSE_0=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("noPassDotGenotype") || a.equalsIgnoreCase("noPassDot")){
-				Var.noPassDotGenotype=Tools.parseBoolean(b);
+				Var.noPassDotGenotype=Parse.parseBoolean(b);
+			}else if(a.equalsIgnoreCase("minVarCopies")){
+				Var.MIN_VAR_COPIES=Integer.parseInt(b);
 			}else if(a.equals("extended")){
-				Var.extendedText=Tools.parseBoolean(b);
+				Var.extendedText=Parse.parseBoolean(b);
 			}else if(a.equals("useidentity")){
-				Var.useIdentity=Tools.parseBoolean(b);
+				Var.useIdentity=Parse.parseBoolean(b);
 			}else if(a.equals("usehomopolymer") || a.equals("homopolymer")){
-				Var.useHomopolymer=Tools.parseBoolean(b);
+				Var.useHomopolymer=Parse.parseBoolean(b);
 			}else if(a.equals("usepairing")){
-				Var.usePairing=Tools.parseBoolean(b);
+				Var.usePairing=Parse.parseBoolean(b);
 			}else if(a.equals("usebias")){
-				Var.useBias=Tools.parseBoolean(b);
+				Var.useBias=Parse.parseBoolean(b);
 			}else if(a.equals("nscan") || a.equals("donscan")){
-				Var.doNscan=Tools.parseBoolean(b);
+				Var.doNscan=Parse.parseBoolean(b);
 			}else if(a.equals("useedist")){
-				Var.useEdist=Tools.parseBoolean(b);
+				Var.useEdist=Parse.parseBoolean(b);
 			}else if(a.equals("prefilter")){
-				prefilter=Tools.parseBoolean(b);
+				prefilter=Parse.parseBoolean(b);
 			}else if(a.equals("ref")){
 				ref=b;
 			}else if(a.equals("vcf") || a.equals("vcfout") || a.equals("outvcf") || a.equals("out")){
@@ -168,17 +171,17 @@ public class CallVariants2 {
 			}
 			
 			else if(a.equals("ca3") || a.equals("32bit")){
-				Scaffold.setCA3(Tools.parseBoolean(b));
+				Scaffold.setCA3(Parse.parseBoolean(b));
 			}else if(a.equals("atomic")){
 				atomic=b;
 			}else if(a.equals("strandedcov") || a.equals("trackstrand")){
-				Scaffold.setTrackStrand(Tools.parseBoolean(b));
+				Scaffold.setTrackStrand(Parse.parseBoolean(b));
 			}
 			
 			else if(a.equals("realign")){
-				realign=Tools.parseBoolean(b);
+				realign=Parse.parseBoolean(b);
 			}else if(a.equals("unclip")){
-				unclip=Tools.parseBoolean(b);
+				unclip=Parse.parseBoolean(b);
 			}else if(a.equals("realignrows") || a.equals("rerows")){
 				Realigner.defaultMaxrows=Integer.parseInt(b);
 			}else if(a.equals("realigncols") || a.equals("recols")){
@@ -193,6 +196,10 @@ public class CallVariants2 {
 				//do nothing
 			}
 			
+			else if(a.equalsIgnoreCase("countNearbyVars")){
+				countNearbyVars=Parse.parseBoolean(b);
+			}
+			
 			else if(a.equals("in") || a.equals("in1") || a.equals("in2")){
 				assert(b!=null) : "Bad parameter: "+arg;
 				if(new File(b).exists()){in.add(b);}
@@ -204,7 +211,7 @@ public class CallVariants2 {
 					in.add(line);
 				}
 			}else if(a.equals("clearfilters")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					varFilter.clear();
 					samFilter.clear();
 				}
@@ -239,7 +246,7 @@ public class CallVariants2 {
 		}
 		
 		if("auto".equalsIgnoreCase(atomic)){Scaffold.setCA3A(Shared.threads()>8);}
-		else{Scaffold.setCA3A(Tools.parseBoolean(atomic));}
+		else{Scaffold.setCA3A(Parse.parseBoolean(atomic));}
 		
 		if(ploidy<1){System.err.println("WARNING: ploidy not set; assuming ploidy=1."); ploidy=1;}
 		samFilter.setSamtoolsFilter();
@@ -567,6 +574,20 @@ public class CallVariants2 {
 			t2.stop("Time: ");
 			outstream.println();
 			
+			if(countNearbyVars){
+				t2.start("Counting nearby variants.");
+				int x=varMap.countNearbyVars(varFilter);
+				if(x>0 && varFilter.failNearby){
+					for(Var v : varMap.toArray(false)){
+						if(!v.forced() && v.nearbyVarCount>varFilter.maxNearbyCount){
+							varMap.removeUnsynchronized(v);
+						}
+					}
+				}
+				t2.stop("Time: ");
+				outstream.println();
+			}
+			
 			long added=0;
 			if(forcedVarsOut!=null){
 				for(Var v : varMap){
@@ -1232,6 +1253,13 @@ public class CallVariants2 {
 
 	public boolean prefilter=false;
 	
+	/* 
+	 * These cover junk due to artifacts, misassemblies, or structural variants,
+	 * which generally result in a rainbow of adjacent SNPs.
+	 * Some fields are in VarFilter.
+	 */
+	public boolean countNearbyVars=true;
+	
 	/*--------------------------------------------------------------*/
 	/*----------------         Final Fields         ----------------*/
 	/*--------------------------------------------------------------*/
