@@ -225,7 +225,7 @@ public class ScafMap {
 		return number>=size() ? null : list.get(number);
 	}
 	
-	public Scaffold getScaffold(String s){
+	public Scaffold getScaffold(final String s){
 		Scaffold value=map.get(s);
 		if(value==null){value=alt.get(s);}
 		if(value==null && TRIM_WHITESPACE_ALSO){
@@ -236,13 +236,14 @@ public class ScafMap {
 					break;
 				}
 			}
+			String sub=null;
 			if(index>0){
-				String sub=s.substring(0, index);
+				sub=s.substring(0, index);
 				value=alt.get(sub);
 				if(value==null){value=map.get(sub);}
 			}
-			assert(value!=null) : "Scaffold not present in reference: "+s+"\n"+index+"\n"+s.substring(0, Tools.max(1, index))
-				+"\n"+keySet()+"\n"+altKeySet()+"\n";
+			assert(value!=null) : "Scaffold not present in reference: "+s+"\nwhitespace="+index+
+				"\nsubstring="+sub+"\nkeySet="+keySet()+"\naltSet="+altKeySet()+"\n";
 		}
 		assert(value!=null) : s+"\n"+keySet()+"\n"+altKeySet()+"\n";
 		return value;
