@@ -19,7 +19,8 @@ public class VcfWriter {
 	/*--------------------------------------------------------------*/
 	
 	public VcfWriter(VarMap varMap_, VarFilter filter_, long reads_,
-			long pairs_, long properPairs_, long bases_, String ref_, boolean trimWhitespace_, String sampleName_){
+			long pairs_, long properPairs_, long bases_, String ref_,
+			boolean trimWhitespace_, String sampleName_){
 		
 		varMap=varMap_;
 		filter=filter_;
@@ -240,22 +241,23 @@ public class VcfWriter {
 			ListNum<Var> list=takeVars();
 			final ByteBuilder bb=new ByteBuilder();
 			while(list!=null && list.size()>0 && list!=POISON_VARS){
-				if(mode==VCFMODE){
-					for(Var v : list){
-						v.toVCF(bb, properPairRate, totalQualityAvg, totalMapqAvg, readLengthAvg, ploidy, scafMap, filter, trimWhitespace);
-						bb.nl();
-					}
-				}else if(mode==VARMODE){
-					for(Var v : list){
-						v.toText(bb, properPairRate, totalQualityAvg, totalMapqAvg, readLengthAvg, filter.rarity, ploidy, scafMap);//TODO: Track depth
-						bb.nl();
-					}
-				}else if(mode==GFFMODE){
-					for(Var v : list){
-						GffLine.toText(bb, v, properPairRate, totalQualityAvg, totalMapqAvg, readLengthAvg, filter.rarity, ploidy, scafMap);
+				
+//				(filter==null ? true :
+//					filter.passesFilter(this, properPairRate, totalQualityAvg, mapqAvg, readLengthAvg, ploidy, map, true));
+				
+				for(Var v : list){
+					if(v.forced() || filter==null || !filter.failNearby || v.nearbyVarCount<=filter.maxNearbyCount){
+						if(mode==VCFMODE){
+							v.toVCF(bb, properPairRate, totalQualityAvg, totalMapqAvg, readLengthAvg, ploidy, scafMap, filter, trimWhitespace);
+						}else if(mode==VARMODE){
+							v.toText(bb, properPairRate, totalQualityAvg, totalMapqAvg, readLengthAvg, filter.rarity, ploidy, scafMap);//TODO: Track depth
+						}else if(mode==GFFMODE){
+							GffLine.toText(bb, v, properPairRate, totalQualityAvg, totalMapqAvg, readLengthAvg, filter.rarity, ploidy, scafMap);
+						}
 						bb.nl();
 					}
 				}
+				
 				bsw.add(new ByteBuilder(bb.toBytes()), list.id);
 				list=takeVars();
 				
