@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified August 24, 2015
+Last modified April 3, 2020
 
 Description:  Filters a sam file to select only reads with substitution errors
 for bases with quality scores in a certain interval.  Used for manually 
@@ -17,6 +17,7 @@ out=<file>      Output file.
 minq=0          Keep only reads with substitutions of at least this quality.
 maxq=99         Keep only reads with substitutions of at most this quality.
 countindels=t   Also keep reads with indels in the quality range. 
+minsubs=1       Require at least this many substitutions.
 keepperfect=f   Also keep error-free reads.
 
 Please contact Brian Bushnell at bbushnell@lbl.gov if you encounter any problems.
