@@ -27,8 +27,8 @@ NOTE: "length" parameters dictate subread length (for normal reads).
 minlen=500      (minlength) Minimum length of genomic sequence molecules.
 maxlen=5000     (maxlength) Maximum length of genomic sequence molecules.
 len=            (length) Set minlen and maxlen to the same number.
-minmovie=       (minmov) Minimum length of movies.
-maxmovie=       (maxmov) Maximum length of movies.
+minmovie=500    (minmov) Minimum length of movies.
+maxmovie=40k    (maxmov) Maximum length of movies.
 movie=          (mov) Set minmov and maxmov to the same number.
 
 Ice cream parameters:
