@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified July 17, 2018
+Last modified October 17, 2019
 
 Description:  Generates a random, (probably) repeat-free genome.
 
@@ -19,6 +19,8 @@ gc=0.5          GC fraction.
 nopoly=f        Ban homopolymers.
 pad=0           Add this many Ns to contig ends; does not count toward 
                 genome size.
+amino=f         Produce random amino acids instead of nucleotides.
+includestop=f   Include stop codons in random amino sequences.
 
 Please contact Brian Bushnell at bbushnell@lbl.gov if you encounter any problems.
 "
